import { IsFocusVisibleClassName } from '@uifabric-vue/utilities';
import { getScreenSelector, ScreenWidthMaxSmall, ScreenWidthMinMedium, ScreenWidthMaxMedium, getGlobalClassNames, FontWeights, HighContrastSelector, getFocusStyle } from '@uifabric/styling';
import '../node_modules/core-js/modules/es.symbol.js';
import '../node_modules/core-js/modules/es.array.filter.js';
import '../node_modules/core-js/modules/es.array.for-each.js';
import '../node_modules/core-js/modules/es.object.define-properties.js';
import '../node_modules/core-js/modules/es.object.define-property.js';
import '../node_modules/core-js/modules/es.object.get-own-property-descriptor.js';
import '../node_modules/core-js/modules/es.object.get-own-property-descriptors.js';
import '../node_modules/core-js/modules/es.object.keys.js';
import '../node_modules/core-js/modules/web.dom-collections.for-each.js';
import _defineProperty from '@babel/runtime/helpers/defineProperty';
import '../node_modules/core-js/modules/es.string.small.js';

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }
var GlobalClassNames = {
  root: 'ms-Breadcrumb',
  list: 'ms-Breadcrumb-list',
  listItem: 'ms-Breadcrumb-listItem',
  chevron: 'ms-Breadcrumb-chevron',
  overflow: 'ms-Breadcrumb-overflow',
  overflowButton: 'ms-Breadcrumb-overflowButton',
  itemLink: 'ms-Breadcrumb-itemLink',
  item: 'ms-Breadcrumb-item'
};
var SingleLineTextStyle = {
  whiteSpace: 'nowrap',
  textOverflow: 'ellipsis',
  overflow: 'hidden'
};
var overflowButtonFontSize = 16;
var chevronSmallFontSize = 8;
var itemLineHeight = 36;
var itemFontSize = 18;
var MinimumScreenSelector = getScreenSelector(0, ScreenWidthMaxSmall);
var MediumScreenSelector = getScreenSelector(ScreenWidthMinMedium, ScreenWidthMaxMedium);
var getStyles = function getStyles(props) {
  var _selectors2, _objectSpread2;

  var className = props.className,
      theme = props.theme;
  var palette = theme.palette,
      semanticColors = theme.semanticColors,
      fonts = theme.fonts;
  var classNames = getGlobalClassNames(GlobalClassNames, theme);
  var itemBackgroundHoveredColor = semanticColors.menuItemBackgroundHovered;
  var itemBackgroundPressedColor = semanticColors.menuItemBackgroundPressed;
  var itemTextColor = palette.neutralSecondary;
  var itemTextFontWeight = FontWeights.regular;
  var itemTextHoveredOrPressedColor = palette.neutralPrimary;
  var itemLastChildTextColor = palette.neutralPrimary;
  var itemLastChildTextFontWeight = FontWeights.semibold;
  var chevronButtonColor = palette.neutralSecondary;
  var overflowButtonColor = palette.neutralSecondary;
  var lastChildItemStyles = {
    fontWeight: itemLastChildTextFontWeight,
    color: itemLastChildTextColor
  };
  var itemStateSelectors = {
    ':hover': {
      color: itemTextHoveredOrPressedColor,
      backgroundColor: itemBackgroundHoveredColor,
      cursor: 'pointer',
      selectors: _defineProperty({}, HighContrastSelector, {
        color: 'Highlight'
      })
    },
    ':active': {
      backgroundColor: itemBackgroundPressedColor,
      color: itemTextHoveredOrPressedColor
    },
    '&:active:hover': {
      color: itemTextHoveredOrPressedColor,
      backgroundColor: itemBackgroundPressedColor
    },
    '&:active, &:hover, &:active:hover': {
      textDecoration: 'none'
    }
  };
  var commonItemStyles = {
    color: itemTextColor,
    padding: '0 8px',
    lineHeight: itemLineHeight,
    fontSize: itemFontSize,
    fontWeight: itemTextFontWeight
  };
  return {
    root: [classNames.root, fonts.medium, {
      margin: '11px 0 1px'
    }, className],
    list: [classNames.list, {
      whiteSpace: 'nowrap',
      padding: 0,
      margin: 0,
      display: 'flex',
      alignItems: 'stretch'
    }],
    listItem: [classNames.listItem, {
      listStyleType: 'none',
      margin: '0',
      padding: '0',
      display: 'flex',
      position: 'relative',
      alignItems: 'center',
      selectors: {
        '&:last-child .ms-Breadcrumb-itemLink': lastChildItemStyles,
        '&:last-child .ms-Breadcrumb-item': lastChildItemStyles
      }
    }],
    chevron: [classNames.chevron, {
      color: chevronButtonColor,
      fontSize: fonts.small.fontSize,
      selectors: (_selectors2 = {}, _defineProperty(_selectors2, HighContrastSelector, {
        color: 'WindowText',
        MsHighContrastAdjust: 'none'
      }), _defineProperty(_selectors2, MediumScreenSelector, {
        fontSize: chevronSmallFontSize
      }), _defineProperty(_selectors2, MinimumScreenSelector, {
        fontSize: chevronSmallFontSize
      }), _selectors2)
    }],
    overflow: [classNames.overflow, {
      position: 'relative',
      display: 'flex',
      alignItems: 'center'
    }],
    overflowButton: [classNames.overflowButton, getFocusStyle(theme), SingleLineTextStyle, {
      fontSize: overflowButtonFontSize,
      color: overflowButtonColor,
      height: '100%',
      cursor: 'pointer',
      selectors: _objectSpread(_objectSpread({}, itemStateSelectors), {}, (_objectSpread2 = {}, _defineProperty(_objectSpread2, MinimumScreenSelector, {
        padding: '4px 6px'
      }), _defineProperty(_objectSpread2, MediumScreenSelector, {
        fontSize: fonts.mediumPlus.fontSize
      }), _objectSpread2))
    }],
    itemLink: [classNames.itemLink, getFocusStyle(theme), SingleLineTextStyle, _objectSpread(_objectSpread({}, commonItemStyles), {}, {
      selectors: _objectSpread(_defineProperty({
        ':focus': {
          color: palette.neutralDark
        }
      }, ".".concat(IsFocusVisibleClassName, " &:focus"), {
        outline: "none"
      }), itemStateSelectors)
    })],
    item: [classNames.item, _objectSpread(_objectSpread({}, commonItemStyles), {}, {
      selectors: {
        ':hover': {
          cursor: 'default'
        }
      }
    })]
  };
};

export { getStyles };
