import { memoizeFunction } from '@uifabric-vue/utilities';
import { getFocusStyle, HighContrastSelector } from '@uifabric/styling';
import _defineProperty from '@babel/runtime/helpers/defineProperty';
import { concatStyleSets } from '@uifabric/merge-styles';
import { ButtonGlobalClassNames } from '../BaseButton.classNames.js';
import { getStyles as getStyles$1 } from '../BaseButton.styles.js';

var getStyles = memoizeFunction(function (theme, customStyles, focusInset, focusColor) {
  var _selectors2, _selectors3, _selectors4, _selectors5, _selectors6, _selectors9;

  var baseButtonStyles = getStyles$1(theme);
  var baseSplitButtonStyles = {};
  var p = theme.palette,
      semanticColors = theme.semanticColors;
  var commandButtonHighContrastFocus = {
    left: 4,
    top: 4,
    bottom: 4,
    right: 4,
    border: 'none'
  };
  var commandButtonStyles = {
    root: [getFocusStyle(theme, {
      inset: 2,
      highContrastStyle: commandButtonHighContrastFocus,
      borderColor: 'transparent'
    }), theme.fonts.medium, {
      minWidth: '40px',
      backgroundColor: p.white,
      color: p.neutralPrimary,
      padding: '0 4px',
      border: 'none',
      borderRadius: 0,
      selectors: _defineProperty({}, HighContrastSelector, {
        border: 'none'
      })
    }],
    rootHovered: {
      backgroundColor: p.neutralLighter,
      color: p.neutralDark,
      selectors: (_selectors2 = {}, _defineProperty(_selectors2, HighContrastSelector, {
        color: 'Highlight'
      }), _defineProperty(_selectors2, ".".concat(ButtonGlobalClassNames.msButtonIcon), {
        color: p.themeDarkAlt
      }), _defineProperty(_selectors2, ".".concat(ButtonGlobalClassNames.msButtonMenuIcon), {
        color: p.neutralPrimary
      }), _selectors2)
    },
    rootPressed: {
      backgroundColor: p.neutralLight,
      color: p.neutralDark,
      selectors: (_selectors3 = {}, _defineProperty(_selectors3, ".".concat(ButtonGlobalClassNames.msButtonIcon), {
        color: p.themeDark
      }), _defineProperty(_selectors3, ".".concat(ButtonGlobalClassNames.msButtonMenuIcon), {
        color: p.neutralPrimary
      }), _selectors3)
    },
    rootChecked: {
      backgroundColor: p.neutralLight,
      color: p.neutralDark,
      selectors: (_selectors4 = {}, _defineProperty(_selectors4, ".".concat(ButtonGlobalClassNames.msButtonIcon), {
        color: p.themeDark
      }), _defineProperty(_selectors4, ".".concat(ButtonGlobalClassNames.msButtonMenuIcon), {
        color: p.neutralPrimary
      }), _selectors4)
    },
    rootCheckedHovered: {
      backgroundColor: p.neutralQuaternaryAlt,
      selectors: (_selectors5 = {}, _defineProperty(_selectors5, ".".concat(ButtonGlobalClassNames.msButtonIcon), {
        color: p.themeDark
      }), _defineProperty(_selectors5, ".".concat(ButtonGlobalClassNames.msButtonMenuIcon), {
        color: p.neutralPrimary
      }), _selectors5)
    },
    rootExpanded: {
      backgroundColor: p.neutralLight,
      color: p.neutralDark,
      selectors: (_selectors6 = {}, _defineProperty(_selectors6, ".".concat(ButtonGlobalClassNames.msButtonIcon), {
        color: p.themeDark
      }), _defineProperty(_selectors6, ".".concat(ButtonGlobalClassNames.msButtonMenuIcon), {
        color: p.neutralPrimary
      }), _selectors6)
    },
    rootExpandedHovered: {
      backgroundColor: p.neutralQuaternaryAlt
    },
    rootDisabled: {
      backgroundColor: p.white,
      selectors: _defineProperty({}, ".".concat(ButtonGlobalClassNames.msButtonIcon), {
        color: semanticColors.disabledBodySubtext
      })
    },
    splitButtonContainer: {
      height: '100%',
      selectors: _defineProperty({}, HighContrastSelector, {
        border: 'none'
      })
    },
    splitButtonDivider: {
      backgroundColor: p.neutralTertiaryAlt
    },
    splitButtonMenuButton: {
      backgroundColor: p.white,
      border: 'none',
      borderTopRightRadius: '0',
      borderBottomRightRadius: '0',
      color: p.neutralSecondary,
      selectors: {
        ':hover': {
          backgroundColor: p.neutralLighter,
          color: p.neutralDark,
          selectors: (_selectors9 = {}, _defineProperty(_selectors9, HighContrastSelector, {
            color: 'Highlight'
          }), _defineProperty(_selectors9, ".".concat(ButtonGlobalClassNames.msButtonIcon), {
            color: p.neutralPrimary
          }), _selectors9)
        },
        ':active': {
          backgroundColor: p.neutralLight,
          selectors: _defineProperty({}, ".".concat(ButtonGlobalClassNames.msButtonIcon), {
            color: p.neutralPrimary
          })
        }
      }
    },
    splitButtonMenuButtonDisabled: {
      backgroundColor: p.white
    },
    splitButtonMenuButtonChecked: {
      backgroundColor: p.neutralLight,
      color: p.neutralDark,
      selectors: {
        ':hover': {
          backgroundColor: p.neutralQuaternaryAlt
        }
      }
    },
    splitButtonMenuButtonExpanded: {
      backgroundColor: p.neutralLight,
      color: p.black,
      selectors: {
        ':hover': {
          backgroundColor: p.neutralQuaternaryAlt
        }
      }
    },
    splitButtonMenuIcon: {
      color: p.neutralPrimary
    },
    splitButtonMenuIconDisabled: {
      color: p.neutralTertiary
    },
    label: {
      fontWeight: 'normal'
    },
    icon: {
      color: p.themePrimary
    },
    menuIcon: {
      color: p.neutralSecondary
    }
  };
  return concatStyleSets(baseButtonStyles, baseSplitButtonStyles, commandButtonStyles, customStyles);
});

export { getStyles };
