import '../node_modules/core-js/modules/es.array.concat.js';
import { memoizeFunction, IsFocusVisibleClassName } from '@uifabric-vue/utilities';
import { getScreenSelector, ScreenWidthMaxMedium, mergeStyleSets, getGlobalClassNames } from '@uifabric/styling';
import _defineProperty from '@babel/runtime/helpers/defineProperty';
import { getMenuItemStyles } from './ContextualMenu.cnstyles.js';
import { getDividerClassNames } from '../Divider/VerticalDivider.classNames.js';

var CONTEXTUAL_SPLIT_MENU_MINWIDTH = '28px';
var MediumScreenSelector = getScreenSelector(0, ScreenWidthMaxMedium);
var getSplitButtonVerticalDividerClassNames = memoizeFunction(function (theme) {
  return mergeStyleSets(getDividerClassNames(theme), {
    wrapper: {
      position: 'absolute',
      right: 28,
      selectors: _defineProperty({}, MediumScreenSelector, {
        right: 32
      })
    },
    divider: {
      height: 16,
      width: 1
    }
  });
});
var GlobalClassNames = {
  item: 'ms-ContextualMenu-item',
  divider: 'ms-ContextualMenu-divider',
  root: 'ms-ContextualMenu-link',
  isChecked: 'is-checked',
  isExpanded: 'is-expanded',
  isDisabled: 'is-disabled',
  linkContent: 'ms-ContextualMenu-linkContent',
  linkContentMenu: 'ms-ContextualMenu-linkContent',
  icon: 'ms-ContextualMenu-icon',
  iconColor: 'ms-ContextualMenu-iconColor',
  checkmarkIcon: 'ms-ContextualMenu-checkmarkIcon',
  subMenuIcon: 'ms-ContextualMenu-submenuIcon',
  label: 'ms-ContextualMenu-itemText',
  secondaryText: 'ms-ContextualMenu-secondaryText',
  splitMenu: 'ms-ContextualMenu-splitMenu'
};
var getItemClassNames = memoizeFunction(function (theme, disabled, expanded, checked, isAnchorLink, knownIcon, itemClassName, dividerClassName, iconClassName, subMenuClassName, primaryDisabled, className) {
  var _selectors2, _selectors3, _selectors4;

  var styles = getMenuItemStyles(theme);
  var classNames = getGlobalClassNames(GlobalClassNames, theme);
  return mergeStyleSets({
    item: [classNames.item, styles.item, itemClassName],
    divider: [classNames.divider, styles.divider, dividerClassName],
    root: [classNames.root, styles.root, checked && [classNames.isChecked, styles.rootChecked], isAnchorLink && styles.anchorLink, expanded && [classNames.isExpanded, styles.rootExpanded], disabled && [classNames.isDisabled, styles.rootDisabled], !disabled && !expanded && [{
      selectors: (_selectors2 = {
        ':hover': styles.rootHovered,
        ':active': styles.rootPressed
      }, _defineProperty(_selectors2, ".".concat(IsFocusVisibleClassName, " &:focus, .").concat(IsFocusVisibleClassName, " &:focus:hover"), styles.rootFocused), _defineProperty(_selectors2, ".".concat(IsFocusVisibleClassName, " &:hover"), {
        background: 'inherit;'
      }), _selectors2)
    }], className],
    splitPrimary: [styles.root, {
      width: "calc(100% - ".concat(CONTEXTUAL_SPLIT_MENU_MINWIDTH, ")")
    }, checked && ['is-checked', styles.rootChecked], (disabled || primaryDisabled) && ['is-disabled', styles.rootDisabled], !(disabled || primaryDisabled) && !checked && [{
      selectors: (_selectors3 = {
        ':hover': styles.rootHovered
      }, _defineProperty(_selectors3, ":hover ~ .".concat(classNames.splitMenu), styles.rootHovered), _defineProperty(_selectors3, ':active', styles.rootPressed), _defineProperty(_selectors3, ".".concat(IsFocusVisibleClassName, " &:focus, .").concat(IsFocusVisibleClassName, " &:focus:hover"), styles.rootFocused), _defineProperty(_selectors3, ".".concat(IsFocusVisibleClassName, " &:hover"), {
        background: 'inherit;'
      }), _selectors3)
    }]],
    splitMenu: [classNames.splitMenu, styles.root, {
      flexBasis: '0',
      padding: '0 8px',
      minWidth: CONTEXTUAL_SPLIT_MENU_MINWIDTH
    }, expanded && ['is-expanded', styles.rootExpanded], disabled && ['is-disabled', styles.rootDisabled], !disabled && !expanded && [{
      selectors: (_selectors4 = {
        ':hover': styles.rootHovered,
        ':active': styles.rootPressed
      }, _defineProperty(_selectors4, ".".concat(IsFocusVisibleClassName, " &:focus, .").concat(IsFocusVisibleClassName, " &:focus:hover"), styles.rootFocused), _defineProperty(_selectors4, ".".concat(IsFocusVisibleClassName, " &:hover"), {
        background: 'inherit;'
      }), _selectors4)
    }]],
    anchorLink: styles.anchorLink,
    linkContent: [classNames.linkContent, styles.linkContent],
    linkContentMenu: [classNames.linkContentMenu, styles.linkContent, {
      justifyContent: 'center'
    }],
    icon: [classNames.icon, knownIcon && styles.iconColor, styles.icon, iconClassName, disabled && [classNames.isDisabled, styles.iconDisabled]],
    iconColor: styles.iconColor,
    checkmarkIcon: [classNames.checkmarkIcon, knownIcon && styles.checkmarkIcon, styles.icon, iconClassName],
    subMenuIcon: [classNames.subMenuIcon, styles.subMenuIcon, subMenuClassName, expanded && {
      color: theme.palette.neutralPrimary
    }, disabled && [styles.iconDisabled]],
    label: [classNames.label, styles.label],
    secondaryText: [classNames.secondaryText, styles.secondaryText],
    splitContainer: [styles.splitButtonFlexContainer, !disabled && !checked && [{
      selectors: _defineProperty({}, ".".concat(IsFocusVisibleClassName, " &:focus, .").concat(IsFocusVisibleClassName, " &:focus:hover"), styles.rootFocused)
    }]]
  });
});
var getItemStyles = function getItemStyles(props) {
  var theme = props.theme,
      disabled = props.disabled,
      expanded = props.expanded,
      checked = props.checked,
      isAnchorLink = props.isAnchorLink,
      knownIcon = props.knownIcon,
      itemClassName = props.itemClassName,
      dividerClassName = props.dividerClassName,
      iconClassName = props.iconClassName,
      subMenuClassName = props.subMenuClassName,
      primaryDisabled = props.primaryDisabled,
      className = props.className;
  return getItemClassNames(theme, disabled, expanded, checked, isAnchorLink, knownIcon, itemClassName, dividerClassName, iconClassName, subMenuClassName, primaryDisabled, className);
};

export { getItemClassNames, getItemStyles, getSplitButtonVerticalDividerClassNames };
