import '../../node_modules/core-js/modules/es.array.concat.js';
import { getGlobalClassNames, getFocusStyle, FontWeights, hiddenContentStyle } from '@uifabric/styling';
import '../../node_modules/core-js/modules/es.symbol.js';
import '../../node_modules/core-js/modules/es.array.filter.js';
import '../../node_modules/core-js/modules/es.array.for-each.js';
import '../../node_modules/core-js/modules/es.object.define-properties.js';
import '../../node_modules/core-js/modules/es.object.define-property.js';
import '../../node_modules/core-js/modules/es.object.get-own-property-descriptor.js';
import '../../node_modules/core-js/modules/es.object.get-own-property-descriptors.js';
import '../../node_modules/core-js/modules/es.object.keys.js';
import '../../node_modules/core-js/modules/web.dom-collections.for-each.js';
import _defineProperty from '@babel/runtime/helpers/defineProperty';
import '../../node_modules/core-js/modules/es.string.small.js';
import { DEFAULT_CELL_STYLE_PROPS } from '../DetailsRow/DetailsRow.styles.js';
import { getCellStyles } from '../DetailsHeader/DetailsHeader.styles.js';

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }
var GlobalClassNames = {
  isActionable: 'is-actionable',
  cellIsCheck: 'ms-DetailsHeader-cellIsCheck',
  collapseButton: 'ms-DetailsHeader-collapseButton',
  isCollapsed: 'is-collapsed',
  isAllSelected: 'is-allSelected',
  isSelectAllHidden: 'is-selectAllHidden',
  isResizingColumn: 'is-resizingColumn',
  isEmpty: 'is-empty',
  isIconVisible: 'is-icon-visible',
  cellSizer: 'ms-DetailsHeader-cellSizer',
  isResizing: 'is-resizing',
  dropHintCircleStyle: 'ms-DetailsHeader-dropHintCircleStyle',
  dropHintLineStyle: 'ms-DetailsHeader-dropHintLineStyle',
  cellTitle: 'ms-DetailsHeader-cellTitle',
  cellName: 'ms-DetailsHeader-cellName',
  filterChevron: 'ms-DetailsHeader-filterChevron',
  gripperBarVerticalStyle: 'ms-DetailsColumn-gripperBar',
  nearIcon: 'ms-DetailsColumn-nearIcon'
};
var getStyles = function getStyles(props) {
  var theme = props.theme,
      headerClassName = props.headerClassName,
      iconClassName = props.iconClassName,
      isActionable = props.isActionable,
      isEmpty = props.isEmpty,
      isIconVisible = props.isIconVisible,
      isPadded = props.isPadded,
      isIconOnly = props.isIconOnly,
      _props$cellStyleProps = props.cellStyleProps,
      cellStyleProps = _props$cellStyleProps === void 0 ? DEFAULT_CELL_STYLE_PROPS : _props$cellStyleProps,
      transitionDurationDrag = props.transitionDurationDrag,
      transitionDurationDrop = props.transitionDurationDrop;
  var semanticColors = theme.semanticColors,
      palette = theme.palette,
      fonts = theme.fonts;
  var classNames = getGlobalClassNames(GlobalClassNames, theme);
  var colors = {
    iconForegroundColor: semanticColors.bodySubtext,
    headerForegroundColor: semanticColors.bodyText,
    headerBackgroundColor: semanticColors.bodyBackground,
    dropdownChevronForegroundColor: palette.neutralTertiary,
    resizerColor: palette.neutralTertiaryAlt
  };
  var nearIconStyle = {
    color: colors.iconForegroundColor,
    opacity: 1,
    paddingLeft: 8
  };
  var borderWhileDragging = {
    outline: "1px solid ".concat(palette.themePrimary)
  };
  var borderAfterDragOrDrop = {
    outlineColor: 'transparent'
  };
  return {
    root: [getCellStyles(props), fonts.small, isActionable && [classNames.isActionable, {
      selectors: {
        ':hover': {
          color: semanticColors.bodyText,
          background: semanticColors.listHeaderBackgroundHovered
        },
        ':active': {
          background: semanticColors.listHeaderBackgroundPressed
        }
      }
    }], isEmpty && [classNames.isEmpty, {
      textOverflow: 'clip'
    }], isIconVisible && classNames.isIconVisible, isPadded && {
      paddingRight: cellStyleProps.cellExtraRightPadding + cellStyleProps.cellRightPadding
    }, {
      selectors: {
        ':hover i[data-icon-name="GripperBarVertical"]': {
          display: 'block'
        }
      }
    }, headerClassName],
    gripperBarVerticalStyle: {
      display: 'none',
      position: 'absolute',
      textAlign: 'left',
      color: palette.neutralTertiary,
      left: 1
    },
    nearIcon: [classNames.nearIcon, nearIconStyle],
    sortIcon: [nearIconStyle, {
      paddingLeft: 4,
      position: 'relative',
      top: 1
    }],
    iconClassName: [{
      color: colors.iconForegroundColor,
      opacity: 1
    }, iconClassName],
    filterChevron: [classNames.filterChevron, {
      color: colors.dropdownChevronForegroundColor,
      paddingLeft: 6,
      verticalAlign: 'middle',
      fontSize: fonts.small.fontSize
    }],
    cellTitle: [classNames.cellTitle, getFocusStyle(theme), _objectSpread({
      display: 'flex',
      flexDirection: 'row',
      justifyContent: 'flex-start',
      alignItems: 'stretch',
      boxSizing: 'border-box',
      overflow: 'hidden',
      padding: "0 ".concat(cellStyleProps.cellRightPadding, "px 0 ").concat(cellStyleProps.cellLeftPadding, "px")
    }, isIconOnly ? {
      alignContent: 'flex-end',
      maxHeight: '100%',
      flexWrap: 'wrap-reverse'
    } : {})],
    cellName: [classNames.cellName, {
      flex: '0 1 auto',
      overflow: 'hidden',
      textOverflow: 'ellipsis',
      fontWeight: FontWeights.semibold,
      fontSize: fonts.medium.fontSize
    }, isIconOnly && {
      selectors: _defineProperty({}, ".".concat(classNames.nearIcon), {
        paddingLeft: 0
      })
    }],
    cellTooltip: {
      display: 'block',
      position: 'absolute',
      top: 0,
      left: 0,
      bottom: 0,
      right: 0
    },
    accessibleLabel: hiddenContentStyle,
    borderWhileDragging: borderWhileDragging,
    noBorderWhileDragging: [borderAfterDragOrDrop, {
      transition: "outline ".concat(transitionDurationDrag, "ms ease")
    }],
    borderAfterDropping: borderWhileDragging,
    noBorderAfterDropping: [borderAfterDragOrDrop, {
      transition: "outline  ".concat(transitionDurationDrop, "ms ease")
    }]
  };
};

export { getStyles };
