import '../node_modules/core-js/modules/es.array.concat.js';
import { IsFocusVisibleClassName, RectangleEdge } from '@uifabric-vue/utilities';
import { HighContrastSelector, HighContrastSelectorWhite, getScreenSelector, ScreenWidthMinMedium, getGlobalClassNames, normalize, FontWeights } from '@uifabric/styling';
import '../node_modules/core-js/modules/es.symbol.js';
import '../node_modules/core-js/modules/es.array.filter.js';
import '../node_modules/core-js/modules/es.array.for-each.js';
import '../node_modules/core-js/modules/es.object.define-properties.js';
import '../node_modules/core-js/modules/es.object.define-property.js';
import '../node_modules/core-js/modules/es.object.get-own-property-descriptor.js';
import '../node_modules/core-js/modules/es.object.get-own-property-descriptors.js';
import '../node_modules/core-js/modules/es.object.keys.js';
import '../node_modules/core-js/modules/web.dom-collections.for-each.js';
import _defineProperty from '@babel/runtime/helpers/defineProperty';
import '../node_modules/core-js/modules/es.string.small.js';
import '../node_modules/core-js/modules/es.regexp.exec.js';
import '../node_modules/core-js/modules/es.string.replace.js';

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }
var GlobalClassNames = {
  root: 'ms-Dropdown-container',
  label: 'ms-Dropdown-label',
  dropdown: 'ms-Dropdown',
  title: 'ms-Dropdown-title',
  caretDownWrapper: 'ms-Dropdown-caretDownWrapper',
  caretDown: 'ms-Dropdown-caretDown',
  callout: 'ms-Dropdown-callout',
  panel: 'ms-Dropdown-panel',
  dropdownItems: 'ms-Dropdown-items',
  dropdownItem: 'ms-Dropdown-item',
  dropdownDivider: 'ms-Dropdown-divider',
  dropdownOptionText: 'ms-Dropdown-optionText',
  dropdownItemHeader: 'ms-Dropdown-header',
  titleIsPlaceHolder: 'ms-Dropdown-titleIsPlaceHolder',
  titleHasError: 'ms-Dropdown-title--hasError'
};
var DROPDOWN_HEIGHT = 32;
var DROPDOWN_ITEM_HEIGHT = 36;

var highContrastAdjustMixin = _defineProperty({}, "".concat(HighContrastSelector, ", ").concat(HighContrastSelectorWhite.replace('@media ', '')), {
  MsHighContrastAdjust: 'none'
});

var highContrastItemAndTitleStateMixin = {
  selectors: _objectSpread(_defineProperty({}, HighContrastSelector, {
    backgroundColor: 'Highlight',
    borderColor: 'Highlight',
    color: 'HighlightText'
  }), highContrastAdjustMixin)
};
var highContrastBorderState = {
  selectors: _defineProperty({}, HighContrastSelector, {
    borderColor: 'Highlight'
  })
};
var MinimumScreenSelector = getScreenSelector(0, ScreenWidthMinMedium);
var getStyles = function getStyles(props) {
  var _selectors3;

  var theme = props.theme,
      hasError = props.hasError,
      hasLabel = props.hasLabel,
      className = props.className,
      isOpen = props.isOpen,
      disabled = props.disabled,
      required = props.required,
      isRenderingPlaceholder = props.isRenderingPlaceholder,
      panelClassName = props.panelClassName,
      calloutClassName = props.calloutClassName,
      calloutRenderEdge = props.calloutRenderEdge;

  if (!theme) {
    throw new Error('theme is undefined or null in base Dropdown getStyles function.');
  }

  var globalClassnames = getGlobalClassNames(GlobalClassNames, theme);
  var palette = theme.palette,
      semanticColors = theme.semanticColors,
      effects = theme.effects,
      fonts = theme.fonts;
  var rootHoverFocusActiveSelectorNeutralDarkMixin = {
    color: semanticColors.menuItemTextHovered
  };
  var rootHoverFocusActiveSelectorNeutralPrimaryMixin = {
    color: palette.neutralPrimary
  };
  var borderColorError = {
    borderColor: semanticColors.errorText
  };
  var dropdownItemStyle = [globalClassnames.dropdownItem, {
    backgroundColor: 'transparent',
    boxSizing: 'border-box',
    cursor: 'pointer',
    display: 'flex',
    alignItems: 'center',
    padding: '0 8px',
    width: '100%',
    minHeight: DROPDOWN_ITEM_HEIGHT,
    lineHeight: 20,
    height: 0,
    position: 'relative',
    border: '1px solid transparent',
    borderRadius: 0,
    wordWrap: 'break-word',
    overflowWrap: 'break-word',
    textAlign: 'left'
  }];

  var itemSelectors = function itemSelectors() {
    var _selectors2;

    var isSelected = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : false;
    return {
      selectors: (_selectors2 = {
        '&:hover:focus': [{
          color: palette.neutralDark,
          backgroundColor: !isSelected ? palette.neutralLighter : palette.neutralLight
        }, highContrastItemAndTitleStateMixin],
        '&:focus': [{
          backgroundColor: !isSelected ? 'transparent' : palette.neutralLight
        }, highContrastItemAndTitleStateMixin],
        '&:active': [{
          color: palette.neutralDark,
          backgroundColor: !isSelected ? palette.neutralLighter : palette.neutralLight
        }, highContrastItemAndTitleStateMixin]
      }, _defineProperty(_selectors2, HighContrastSelector, {
        borderColor: 'Window'
      }), _defineProperty(_selectors2, ".".concat(IsFocusVisibleClassName, " &:focus:after"), {
        left: 0,
        top: 0,
        bottom: 0,
        right: 0
      }), _selectors2)
    };
  };

  var dropdownItemSelected = [].concat(dropdownItemStyle, [{
    backgroundColor: palette.neutralLight,
    color: palette.neutralDark
  }, itemSelectors(true), highContrastItemAndTitleStateMixin]);
  var dropdownItemDisabled = [].concat(dropdownItemStyle, [{
    color: semanticColors.disabledText,
    cursor: 'default'
  }]);
  var titleOpenBorderRadius = calloutRenderEdge === RectangleEdge.bottom ? "".concat(effects.roundedCorner2, " ").concat(effects.roundedCorner2, " 0 0") : "0 0 ".concat(effects.roundedCorner2, " ").concat(effects.roundedCorner2);
  var calloutOpenBorderRadius = calloutRenderEdge === RectangleEdge.bottom ? "0 0 ".concat(effects.roundedCorner2, " ").concat(effects.roundedCorner2) : "".concat(effects.roundedCorner2, " ").concat(effects.roundedCorner2, " 0 0");
  return {
    root: [globalClassnames.root, className],
    label: globalClassnames.label,
    dropdown: [globalClassnames.dropdown, normalize, fonts.medium, {
      color: palette.neutralPrimary,
      borderColor: palette.neutralSecondary,
      position: 'relative',
      outline: 0,
      userSelect: 'none',
      selectors: (_selectors3 = {}, _defineProperty(_selectors3, '&:hover .' + globalClassnames.title, [!disabled && rootHoverFocusActiveSelectorNeutralDarkMixin, {
        borderColor: !isOpen ? palette.neutralPrimary : palette.themePrimary
      }, highContrastBorderState]), _defineProperty(_selectors3, '&:focus .' + globalClassnames.title, [!disabled && rootHoverFocusActiveSelectorNeutralDarkMixin]), _defineProperty(_selectors3, '&:focus:after', [{
        pointerEvents: 'none',
        content: "''",
        position: 'absolute',
        boxSizing: 'border-box',
        top: '0px',
        left: '0px',
        width: '100%',
        height: '100%',
        border: !disabled ? "2px solid ".concat(palette.themePrimary) : 'none',
        borderRadius: '2px'
      }, highContrastItemAndTitleStateMixin]), _defineProperty(_selectors3, '&:active .' + globalClassnames.title, [!disabled && rootHoverFocusActiveSelectorNeutralDarkMixin, {
        borderColor: palette.themePrimary
      }, highContrastBorderState]), _defineProperty(_selectors3, '&:hover .' + globalClassnames.caretDown, !disabled && rootHoverFocusActiveSelectorNeutralPrimaryMixin), _defineProperty(_selectors3, '&:focus .' + globalClassnames.caretDown, [!disabled && rootHoverFocusActiveSelectorNeutralPrimaryMixin, {
        selectors: _objectSpread(_defineProperty({}, HighContrastSelector, {
          color: 'HighlightText'
        }), highContrastAdjustMixin)
      }]), _defineProperty(_selectors3, '&:active .' + globalClassnames.caretDown, !disabled && rootHoverFocusActiveSelectorNeutralPrimaryMixin), _defineProperty(_selectors3, '&:hover .' + globalClassnames.titleIsPlaceHolder, !disabled && rootHoverFocusActiveSelectorNeutralPrimaryMixin), _defineProperty(_selectors3, '&:focus .' + globalClassnames.titleIsPlaceHolder, !disabled && rootHoverFocusActiveSelectorNeutralPrimaryMixin), _defineProperty(_selectors3, '&:active .' + globalClassnames.titleIsPlaceHolder, !disabled && rootHoverFocusActiveSelectorNeutralPrimaryMixin), _defineProperty(_selectors3, '&:hover .' + globalClassnames.titleHasError, borderColorError), _defineProperty(_selectors3, '&:active .' + globalClassnames.titleHasError, borderColorError), _selectors3)
    }, isOpen && 'is-open', disabled && 'is-disabled', required && 'is-required', required && !hasLabel && {
      selectors: _defineProperty({
        ':after': {
          content: "'*'",
          color: semanticColors.errorText,
          position: 'absolute',
          top: -5,
          right: -10
        }
      }, HighContrastSelector, {
        selectors: {
          ':after': {
            right: -14
          }
        }
      })
    }],
    title: [globalClassnames.title, normalize, {
      backgroundColor: semanticColors.inputBackground,
      borderWidth: 1,
      borderStyle: 'solid',
      borderColor: semanticColors.inputBorder,
      borderRadius: isOpen ? titleOpenBorderRadius : effects.roundedCorner2,
      cursor: 'pointer',
      display: 'block',
      height: DROPDOWN_HEIGHT,
      lineHeight: DROPDOWN_HEIGHT - 2,
      padding: "0 28px 0 8px",
      position: 'relative',
      overflow: 'hidden',
      whiteSpace: 'nowrap',
      textOverflow: 'ellipsis'
    }, isRenderingPlaceholder && [globalClassnames.titleIsPlaceHolder, {
      color: semanticColors.inputPlaceholderText
    }], hasError && [globalClassnames.titleHasError, borderColorError], disabled && {
      backgroundColor: semanticColors.disabledBackground,
      border: 'none',
      color: semanticColors.disabledText,
      cursor: 'default',
      selectors: _defineProperty({}, HighContrastSelector, {
        border: '1px solid GrayText',
        color: 'GrayText'
      })
    }],
    caretDownWrapper: [globalClassnames.caretDownWrapper, {
      position: 'absolute',
      top: 1,
      right: 8,
      height: DROPDOWN_HEIGHT,
      lineHeight: DROPDOWN_HEIGHT - 2
    }, !disabled && {
      cursor: 'pointer'
    }],
    caretDown: [globalClassnames.caretDown, {
      color: palette.neutralSecondary,
      fontSize: fonts.small.fontSize,
      pointerEvents: 'none'
    }, disabled && {
      color: semanticColors.disabledText,
      selectors: _defineProperty({}, HighContrastSelector, {
        color: 'GrayText'
      })
    }],
    errorMessage: _objectSpread(_objectSpread({
      color: semanticColors.errorText
    }, theme.fonts.small), {}, {
      paddingTop: 5
    }),
    callout: [globalClassnames.callout, {
      boxShadow: effects.elevation8,
      borderRadius: calloutOpenBorderRadius,
      selectors: {
        '.ms-Callout-main': {
          borderRadius: calloutOpenBorderRadius
        }
      }
    }, calloutClassName],
    dropdownItemsWrapper: {
      selectors: {
        '&:focus': {
          outline: 0
        }
      }
    },
    dropdownItems: [globalClassnames.dropdownItems, {
      display: 'block'
    }],
    dropdownItem: [].concat(dropdownItemStyle, [itemSelectors()]),
    dropdownItemSelected: dropdownItemSelected,
    dropdownItemDisabled: dropdownItemDisabled,
    dropdownItemSelectedAndDisabled: [dropdownItemSelected, dropdownItemDisabled, {
      backgroundColor: 'transparent'
    }],
    dropdownItemHidden: [].concat(dropdownItemStyle, [{
      display: 'none'
    }]),
    dropdownDivider: [globalClassnames.dropdownDivider, {
      height: 1,
      backgroundColor: semanticColors.bodyDivider
    }],
    dropdownOptionText: [globalClassnames.dropdownOptionText, {
      overflow: 'hidden',
      whiteSpace: 'nowrap',
      textOverflow: 'ellipsis',
      minWidth: 0,
      maxWidth: '100%',
      wordWrap: 'break-word',
      overflowWrap: 'break-word',
      margin: '1px'
    }],
    dropdownItemHeader: [globalClassnames.dropdownItemHeader, _objectSpread(_objectSpread({}, fonts.medium), {}, {
      fontWeight: FontWeights.semibold,
      color: semanticColors.menuHeader,
      background: 'none',
      backgroundColor: 'transparent',
      border: 'none',
      height: DROPDOWN_ITEM_HEIGHT,
      lineHeight: DROPDOWN_ITEM_HEIGHT,
      cursor: 'default',
      padding: '0 8px',
      userSelect: 'none',
      textAlign: 'left'
    })],
    subComponentStyles: {
      label: {
        root: {
          display: 'inline-block'
        }
      },
      multiSelectItem: {
        root: {
          padding: 0
        },
        label: {
          alignSelf: 'stretch',
          padding: '0 8px',
          width: '100%'
        }
      },
      panel: {
        root: [panelClassName],
        main: {
          selectors: _defineProperty({}, MinimumScreenSelector, {
            width: 272
          })
        },
        contentInner: {
          padding: '0 0 20px'
        }
      }
    }
  };
};

export { getStyles };
