import { getScreenSelector, ScreenWidthMaxSmall, getGlobalClassNames, IconFontSizes, HighContrastSelector, getFocusStyle } from '@uifabric/styling';
import '../node_modules/core-js/modules/es.symbol.js';
import '../node_modules/core-js/modules/es.array.filter.js';
import '../node_modules/core-js/modules/es.array.for-each.js';
import '../node_modules/core-js/modules/es.object.define-properties.js';
import '../node_modules/core-js/modules/es.object.define-property.js';
import '../node_modules/core-js/modules/es.object.get-own-property-descriptor.js';
import '../node_modules/core-js/modules/es.object.get-own-property-descriptors.js';
import '../node_modules/core-js/modules/es.object.keys.js';
import '../node_modules/core-js/modules/web.dom-collections.for-each.js';
import _defineProperty from '@babel/runtime/helpers/defineProperty';
import '../node_modules/core-js/modules/es.string.small.js';
import { MessageBarType } from './MessageBar.types.js';

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }
var GlobalClassNames = {
  root: 'ms-MessageBar',
  error: 'ms-MessageBar--error',
  blocked: 'ms-MessageBar--blocked',
  severeWarning: 'ms-MessageBar--severeWarning',
  success: 'ms-MessageBar--success',
  warning: 'ms-MessageBar--warning',
  multiline: 'ms-MessageBar-multiline',
  singleline: 'ms-MessageBar-singleline',
  dismissalSingleLine: 'ms-MessageBar-dismissalSingleLine',
  expandingSingleLine: 'ms-MessageBar-expandingSingleLine',
  content: 'ms-MessageBar-content',
  iconContainer: 'ms-MessageBar-icon',
  text: 'ms-MessageBar-text',
  innerText: 'ms-MessageBar-innerText',
  dismissSingleLine: 'ms-MessageBar-dismissSingleLine',
  expandSingleLine: 'ms-MessageBar-expandSingleLine',
  dismissal: 'ms-MessageBar-dismissal',
  expand: 'ms-MessageBar-expand',
  actions: 'ms-MessageBar-actions',
  actionsSingleline: 'ms-MessageBar-actionsSingleLine'
};

var getRootBackground = function getRootBackground(messageBarType, palette, semanticColors) {
  switch (messageBarType) {
    case MessageBarType.error:
    case MessageBarType.blocked:
      return semanticColors.errorBackground;

    case MessageBarType.severeWarning:
      return semanticColors.blockingBackground;

    case MessageBarType.success:
      return semanticColors.successBackground;

    case MessageBarType.warning:
      return semanticColors.warningBackground;
  }

  return palette.neutralLighter;
};

var getIconColor = function getIconColor(messageBarType, palette, semanticColors) {
  switch (messageBarType) {
    case MessageBarType.error:
    case MessageBarType.blocked:
    case MessageBarType.severeWarning:
      return semanticColors.errorText;

    case MessageBarType.success:
      return palette.green;

    case MessageBarType.warning:
      return semanticColors.warningText;
  }

  return palette.neutralSecondary;
};

var getStyles = function getStyles(props) {
  var theme = props.theme,
      className = props.className,
      messageBarType = props.messageBarType,
      onDismiss = props.onDismiss,
      truncated = props.truncated,
      isMultiline = props.isMultiline,
      expandSingleLine = props.expandSingleLine;
  var semanticColors = theme.semanticColors,
      palette = theme.palette,
      fonts = theme.fonts;
  var SmallScreenSelector = getScreenSelector(0, ScreenWidthMaxSmall);
  var classNames = getGlobalClassNames(GlobalClassNames, theme);
  var dismissalAndExpandIconStyle = {
    fontSize: IconFontSizes.xSmall,
    height: 10,
    lineHeight: '10px',
    color: palette.neutralPrimary,
    selectors: _defineProperty({}, HighContrastSelector, {
      MsHighContrastAdjust: 'none',
      color: 'Window'
    })
  };
  var dismissalAndExpandStyle = [getFocusStyle(theme, {
    inset: 1,
    highContrastStyle: {
      outlineOffset: '-4px',
      outlineColor: 'Window'
    },
    borderColor: 'transparent'
  }), {
    flexShrink: 0,
    width: 32,
    height: 32,
    padding: '8px 12px',
    selectors: {
      '& .ms-Button-icon': dismissalAndExpandIconStyle,
      ':hover': {
        backgroundColor: 'transparent'
      },
      ':active': {
        backgroundColor: 'transparent'
      }
    }
  }];
  return {
    root: [classNames.root, theme.fonts.medium, messageBarType === MessageBarType.error && classNames.error, messageBarType === MessageBarType.blocked && classNames.blocked, messageBarType === MessageBarType.severeWarning && classNames.severeWarning, messageBarType === MessageBarType.success && classNames.success, messageBarType === MessageBarType.warning && classNames.warning, isMultiline ? classNames.multiline : classNames.singleline, !isMultiline && onDismiss && classNames.dismissalSingleLine, !isMultiline && truncated && classNames.expandingSingleLine, {
      background: getRootBackground(messageBarType, palette, semanticColors),
      color: palette.neutralPrimary,
      minHeight: 32,
      width: '100%',
      display: 'flex',
      wordBreak: 'break-word',
      selectors: _defineProperty({
        '& .ms-Link': _objectSpread({
          color: palette.themeDark
        }, fonts.small)
      }, HighContrastSelector, {
        background: 'WindowText',
        color: 'Window'
      })
    }, isMultiline && {
      flexDirection: 'column'
    }, className],
    content: [classNames.content, {
      display: 'flex',
      width: '100%',
      lineHeight: 'normal'
    }],
    iconContainer: [classNames.iconContainer, {
      fontSize: IconFontSizes.medium,
      minWidth: 16,
      minHeight: 16,
      display: 'flex',
      flexShrink: 0,
      margin: '8px 0 8px 12px'
    }],
    icon: {
      color: getIconColor(messageBarType, palette, semanticColors),
      selectors: _defineProperty({}, HighContrastSelector, {
        MsHighContrastAdjust: 'none',
        color: 'Window'
      })
    },
    text: [classNames.text, _objectSpread(_objectSpread({
      minWidth: 0,
      display: 'flex',
      flexGrow: 1,
      margin: 8
    }, fonts.small), {}, {
      selectors: _defineProperty({}, HighContrastSelector, {
        MsHighContrastAdjust: 'none'
      })
    }), !onDismiss && {
      marginRight: 12
    }],
    innerText: [classNames.innerText, {
      lineHeight: 16,
      selectors: {
        '& span a': {
          paddingLeft: 4
        }
      }
    }, truncated && {
      overflow: 'visible',
      whiteSpace: 'pre-wrap'
    }, !isMultiline && {
      overflow: 'hidden',
      textOverflow: 'ellipsis',
      whiteSpace: 'nowrap'
    }, !isMultiline && !truncated && {
      selectors: _defineProperty({}, SmallScreenSelector, {
        overflow: 'visible',
        whiteSpace: 'pre-wrap'
      })
    }, expandSingleLine && {
      overflow: 'visible',
      whiteSpace: 'pre-wrap'
    }],
    dismissSingleLine: [classNames.dismissSingleLine],
    expandSingleLine: [classNames.expandSingleLine],
    dismissal: [classNames.dismissal, dismissalAndExpandStyle],
    expand: [classNames.expand, dismissalAndExpandStyle],
    actions: [isMultiline ? classNames.actions : classNames.actionsSingleline, {
      display: 'flex',
      flexGrow: 0,
      flexShrink: 0,
      flexBasis: 'auto',
      flexDirection: 'row-reverse',
      alignItems: 'center',
      margin: '0 12px 0 8px',
      selectors: {
        '& button:nth-child(n+2)': {
          marginLeft: 8
        }
      }
    }, isMultiline && {
      marginBottom: 8
    }, onDismiss && !isMultiline && {
      marginRight: 0
    }]
  };
};

export { getStyles };
