import '../node_modules/core-js/modules/es.array.concat.js';
import { ScreenWidthMinMedium, ScreenWidthMinLarge, ScreenWidthMinXLarge, ScreenWidthMinUhfMobile, ScreenWidthMinXXLarge, getGlobalClassNames, AnimationClassNames, HighContrastSelector, AnimationVariables, IconFontSizes } from '@uifabric/styling';
import '../node_modules/core-js/modules/es.symbol.js';
import '../node_modules/core-js/modules/es.array.filter.js';
import '../node_modules/core-js/modules/es.array.for-each.js';
import '../node_modules/core-js/modules/es.object.define-properties.js';
import '../node_modules/core-js/modules/es.object.define-property.js';
import '../node_modules/core-js/modules/es.object.get-own-property-descriptor.js';
import '../node_modules/core-js/modules/es.object.get-own-property-descriptors.js';
import '../node_modules/core-js/modules/es.object.keys.js';
import '../node_modules/core-js/modules/web.dom-collections.for-each.js';
import _defineProperty from '@babel/runtime/helpers/defineProperty';
import { PanelType } from './Panel.types.js';

var _mediumPanelSelectors, _largePanelSelectors;

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }
var GlobalClassNames = {
  root: 'ms-Panel',
  main: 'ms-Panel-main',
  commands: 'ms-Panel-commands',
  contentInner: 'ms-Panel-contentInner',
  scrollableContent: 'ms-Panel-scrollableContent',
  navigation: 'ms-Panel-navigation',
  closeButton: 'ms-Panel-closeButton ms-PanelAction-close',
  header: 'ms-Panel-header',
  headerText: 'ms-Panel-headerText',
  content: 'ms-Panel-content',
  footer: 'ms-Panel-footer',
  footerInner: 'ms-Panel-footerInner',
  isOpen: 'is-open',
  hasCloseButton: 'ms-Panel--hasCloseButton',
  smallFluid: 'ms-Panel--smFluid',
  smallFixedNear: 'ms-Panel--smLeft',
  smallFixedFar: 'ms-Panel--sm',
  medium: 'ms-Panel--md',
  large: 'ms-Panel--lg',
  largeFixed: 'ms-Panel--fixed',
  extraLarge: 'ms-Panel--xl',
  custom: 'ms-Panel--custom',
  customNear: 'ms-Panel--customLeft'
};
var panelWidth = {
  full: '100%',
  auto: 'auto',
  xs: 272,
  sm: 340,
  md1: 592,
  md2: 644,
  lg: 940
};
var panelMargin = {
  auto: 'auto',
  none: 0,
  md: 48,
  lg: 428,
  xl: 176
};

var smallPanelSelectors = _defineProperty({}, "@media (min-width: ".concat(ScreenWidthMinMedium, "px)"), {
  width: panelWidth.sm
});

var mediumPanelSelectors = (_mediumPanelSelectors = {}, _defineProperty(_mediumPanelSelectors, "@media (min-width: ".concat(ScreenWidthMinLarge, "px)"), {
  width: panelWidth.md1
}), _defineProperty(_mediumPanelSelectors, "@media (min-width: ".concat(ScreenWidthMinXLarge, "px)"), {
  width: panelWidth.md2
}), _mediumPanelSelectors);
var largePanelSelectors = (_largePanelSelectors = {}, _defineProperty(_largePanelSelectors, "@media (min-width: ".concat(ScreenWidthMinUhfMobile, "px)"), {
  left: panelMargin.md,
  width: panelWidth.auto
}), _defineProperty(_largePanelSelectors, "@media (min-width: ".concat(ScreenWidthMinXXLarge, "px)"), {
  left: panelMargin.lg
}), _largePanelSelectors);

var largeFixedPanelSelectors = _defineProperty({}, "@media (min-width: ".concat(ScreenWidthMinXXLarge, "px)"), {
  left: panelMargin.auto,
  width: panelWidth.lg
});

var extraLargePanelSelectors = _defineProperty({}, "@media (min-width: ".concat(ScreenWidthMinXXLarge, "px)"), {
  left: panelMargin.xl
});

var getPanelBreakpoints = function getPanelBreakpoints(type) {
  var selectors;

  switch (type) {
    case PanelType.smallFixedFar:
      selectors = _objectSpread({}, smallPanelSelectors);
      break;

    case PanelType.medium:
      selectors = _objectSpread(_objectSpread({}, smallPanelSelectors), mediumPanelSelectors);
      break;

    case PanelType.large:
      selectors = _objectSpread(_objectSpread(_objectSpread({}, smallPanelSelectors), mediumPanelSelectors), largePanelSelectors);
      break;

    case PanelType.largeFixed:
      selectors = _objectSpread(_objectSpread(_objectSpread(_objectSpread({}, smallPanelSelectors), mediumPanelSelectors), largePanelSelectors), largeFixedPanelSelectors);
      break;

    case PanelType.extraLarge:
      selectors = _objectSpread(_objectSpread(_objectSpread(_objectSpread({}, smallPanelSelectors), mediumPanelSelectors), largePanelSelectors), extraLargePanelSelectors);
      break;
  }

  return selectors;
};

var commandBarHeight = '44px';
var sharedPaddingStyles = {
  paddingLeft: '24px',
  paddingRight: '24px'
};
var getStyles = function getStyles(props) {
  var className = props.className,
      focusTrapZoneClassName = props.focusTrapZoneClassName,
      hasCloseButton = props.hasCloseButton,
      headerClassName = props.headerClassName,
      isAnimating = props.isAnimating,
      isFooterSticky = props.isFooterSticky,
      isFooterAtBottom = props.isFooterAtBottom,
      isOnRightSide = props.isOnRightSide,
      isOpen = props.isOpen,
      isHiddenOnDismiss = props.isHiddenOnDismiss,
      hasCustomNavigation = props.hasCustomNavigation,
      theme = props.theme,
      _props$type = props.type,
      type = _props$type === void 0 ? PanelType.smallFixedFar : _props$type;
  var effects = theme.effects,
      fonts = theme.fonts,
      semanticColors = theme.semanticColors;
  var classNames = getGlobalClassNames(GlobalClassNames, theme);
  var isCustomPanel = type === PanelType.custom || type === PanelType.customNear;
  return {
    root: [classNames.root, theme.fonts.medium, isOpen && classNames.isOpen, hasCloseButton && classNames.hasCloseButton, {
      pointerEvents: 'none',
      position: 'absolute',
      top: 0,
      left: 0,
      right: 0,
      bottom: 0
    }, isCustomPanel && isOnRightSide && classNames.custom, isCustomPanel && !isOnRightSide && classNames.customNear, className],
    overlay: [{
      pointerEvents: 'auto',
      cursor: 'pointer'
    }, isOpen && isAnimating && AnimationClassNames.fadeIn100, !isOpen && isAnimating && AnimationClassNames.fadeOut100],
    hiddenPanel: [!isOpen && !isAnimating && isHiddenOnDismiss && {
      visibility: 'hidden'
    }],
    main: [classNames.main, {
      backgroundColor: semanticColors.bodyBackground,
      boxShadow: effects.elevation64,
      pointerEvents: 'auto',
      position: 'absolute',
      display: 'flex',
      flexDirection: 'column',
      overflowX: 'hidden',
      overflowY: 'auto',
      WebkitOverflowScrolling: 'touch',
      bottom: 0,
      top: 0,
      left: panelMargin.auto,
      right: panelMargin.none,
      width: panelWidth.full,
      selectors: _objectSpread(_defineProperty({}, HighContrastSelector, {
        borderLeft: "3px solid ".concat(semanticColors.variantBorder),
        borderRight: "3px solid ".concat(semanticColors.variantBorder)
      }), getPanelBreakpoints(type))
    }, type === PanelType.smallFluid && {
      left: panelMargin.none
    }, type === PanelType.smallFixedNear && {
      left: panelMargin.none,
      right: panelMargin.auto,
      width: panelWidth.xs
    }, type === PanelType.customNear && {
      right: 'auto',
      left: 0
    }, isCustomPanel && {
      maxWidth: '100vw'
    }, isOpen && isAnimating && !isOnRightSide && AnimationClassNames.slideRightIn40, isOpen && isAnimating && isOnRightSide && AnimationClassNames.slideLeftIn40, !isOpen && isAnimating && !isOnRightSide && AnimationClassNames.slideLeftOut40, !isOpen && isAnimating && isOnRightSide && AnimationClassNames.slideRightOut40, focusTrapZoneClassName],
    commands: [classNames.commands, {
      marginTop: 18
    }, hasCustomNavigation && {
      marginTop: 'inherit'
    }],
    navigation: [classNames.navigation, {
      display: 'flex',
      justifyContent: 'flex-end'
    }, hasCustomNavigation && {
      height: commandBarHeight
    }],
    contentInner: [classNames.contentInner, {
      display: 'flex',
      flexDirection: 'column',
      flexGrow: 1,
      overflowY: 'hidden'
    }],
    header: [classNames.header, sharedPaddingStyles, {
      alignSelf: 'flex-start'
    }, hasCloseButton && !hasCustomNavigation && {
      flexGrow: 1
    }, hasCustomNavigation && {
      flexShrink: 0
    }],
    headerText: [classNames.headerText, fonts.xLarge, {
      color: semanticColors.bodyText,
      lineHeight: '27px',
      overflowWrap: 'break-word',
      wordWrap: 'break-word',
      wordBreak: 'break-word',
      hyphens: 'auto'
    }, headerClassName],
    scrollableContent: [classNames.scrollableContent, {
      overflowY: 'auto'
    }, isFooterAtBottom && {
      flexGrow: 1
    }],
    content: [classNames.content, sharedPaddingStyles, {
      paddingBottom: 20
    }],
    footer: [classNames.footer, {
      flexShrink: 0,
      borderTop: '1px solid transparent',
      transition: "opacity ".concat(AnimationVariables.durationValue3, " ").concat(AnimationVariables.easeFunction2)
    }, isFooterSticky && {
      background: semanticColors.bodyBackground,
      borderTopColor: semanticColors.variantBorder
    }],
    footerInner: [classNames.footerInner, sharedPaddingStyles, {
      paddingBottom: 16,
      paddingTop: 16
    }],
    subComponentStyles: {
      closeButton: {
        root: [classNames.closeButton, {
          marginRight: 14,
          color: theme.palette.neutralSecondary,
          fontSize: IconFontSizes.large
        }, hasCustomNavigation && {
          marginRight: 0,
          height: 'auto',
          width: '44px'
        }],
        rootHovered: {
          color: theme.palette.neutralPrimary
        }
      }
    }
  };
};

export { getStyles };
