import '../node_modules/core-js/modules/es.array.concat.js';
import { getRTL } from '@uifabric-vue/utilities';
import { getGlobalClassNames, noWrap, HighContrastSelector } from '@uifabric/styling';
import _defineProperty from '@babel/runtime/helpers/defineProperty';
import { keyframes } from '@uifabric/merge-styles';
import '../node_modules/core-js/modules/es.string.small.js';

var GlobalClassNames = {
  root: 'ms-ProgressIndicator',
  itemName: 'ms-ProgressIndicator-itemName',
  itemDescription: 'ms-ProgressIndicator-itemDescription',
  itemProgress: 'ms-ProgressIndicator-itemProgress',
  progressTrack: 'ms-ProgressIndicator-progressTrack',
  progressBar: 'ms-ProgressIndicator-progressBar'
};
var IndeterminateProgress = keyframes({
  '0%': {
    left: '-30%'
  },
  '100%': {
    left: '100%'
  }
});
var IndeterminateProgressRTL = keyframes({
  '100%': {
    right: '-30%'
  },
  '0%': {
    right: '100%'
  }
});
var getStyles = function getStyles(props) {
  var isRTL = getRTL();
  var className = props.className,
      indeterminate = props.indeterminate,
      theme = props.theme,
      _props$barHeight = props.barHeight,
      barHeight = _props$barHeight === void 0 ? 2 : _props$barHeight;
  var palette = theme.palette,
      semanticColors = theme.semanticColors,
      fonts = theme.fonts;
  var classNames = getGlobalClassNames(GlobalClassNames, theme);
  var marginBetweenText = 8;
  var textHeight = 18;
  var progressTrackColor = palette.neutralLight;
  return {
    root: [classNames.root, fonts.medium, className],
    itemName: [classNames.itemName, noWrap, {
      color: semanticColors.bodyText,
      paddingTop: marginBetweenText / 2,
      lineHeight: textHeight + 2
    }],
    itemDescription: [classNames.itemDescription, {
      color: semanticColors.bodySubtext,
      fontSize: fonts.small.fontSize,
      lineHeight: textHeight
    }],
    itemProgress: [classNames.itemProgress, {
      position: 'relative',
      overflow: 'hidden',
      height: barHeight,
      padding: "".concat(marginBetweenText, "px 0")
    }],
    progressTrack: [classNames.progressTrack, {
      position: 'absolute',
      width: '100%',
      height: barHeight,
      backgroundColor: progressTrackColor,
      selectors: _defineProperty({}, HighContrastSelector, {
        borderBottom: '1px solid WindowText'
      })
    }],
    progressBar: [{
      backgroundColor: palette.themePrimary,
      height: barHeight,
      position: 'absolute',
      transition: 'width .3s ease',
      width: 0,
      selectors: _defineProperty({}, HighContrastSelector, {
        backgroundColor: 'WindowText'
      })
    }, indeterminate ? {
      position: 'absolute',
      minWidth: '33%',
      background: "linear-gradient(to right, ".concat(progressTrackColor, " 0%, ").concat(palette.themePrimary, " 50%, ").concat(progressTrackColor, " 100%)"),
      animation: "".concat(isRTL ? IndeterminateProgressRTL : IndeterminateProgress, " 3s infinite")
    } : {
      transition: 'width .15s linear'
    }, classNames.progressBar]
  };
};

export { getStyles };
