import '../node_modules/core-js/modules/es.array.concat.js';
import { getRTL } from '@uifabric-vue/utilities';
import { getGlobalClassNames, HighContrastSelector, getFocusStyle, AnimationVariables } from '@uifabric/styling';
import _defineProperty from '@babel/runtime/helpers/defineProperty';

var GlobalClassNames = {
  root: 'ms-Slider',
  enabled: 'ms-Slider-enabled',
  disabled: 'ms-Slider-disabled',
  row: 'ms-Slider-row',
  column: 'ms-Slider-column',
  container: 'ms-Slider-container',
  slideBox: 'ms-Slider-slideBox',
  line: 'ms-Slider-line',
  thumb: 'ms-Slider-thumb',
  activeSection: 'ms-Slider-active',
  inactiveSection: 'ms-Slider-inactive',
  valueLabel: 'ms-Slider-value',
  showValue: 'ms-Slider-showValue',
  showTransitions: 'ms-Slider-showTransitions',
  zeroTick: 'ms-Slider-zeroTick'
};
var getStyles = function getStyles(props) {
  var _selectors6;

  var className = props.className,
      titleLabelClassName = props.titleLabelClassName,
      theme = props.theme,
      vertical = props.vertical,
      disabled = props.disabled,
      showTransitions = props.showTransitions,
      showValue = props.showValue;
  var semanticColors = theme.semanticColors;
  var classNames = getGlobalClassNames(GlobalClassNames, theme);
  var pressedActiveSectionColor = semanticColors.inputBackgroundCheckedHovered;
  var hoveredActiveSectionColor = semanticColors.inputBackgroundChecked;
  var hoveredPressedinactiveSectionColor = semanticColors.inputPlaceholderBackgroundChecked;
  var restActiveSectionColor = semanticColors.smallInputBorder;
  var restInactiveSectionColor = semanticColors.disabledBorder;
  var disabledActiveSectionColor = semanticColors.disabledText;
  var disabledInactiveSectionColor = semanticColors.disabledBackground;
  var thumbBackgroundColor = semanticColors.inputBackground;
  var thumbBorderColor = semanticColors.smallInputBorder;
  var thumbDisabledBorderColor = semanticColors.disabledBorder;
  var slideBoxActiveSectionStyles = !disabled && {
    backgroundColor: pressedActiveSectionColor,
    selectors: _defineProperty({}, HighContrastSelector, {
      backgroundColor: 'Highlight'
    })
  };
  var slideBoxInactiveSectionStyles = !disabled && {
    backgroundColor: hoveredPressedinactiveSectionColor,
    selectors: _defineProperty({}, HighContrastSelector, {
      borderColor: 'Highlight'
    })
  };
  var slideHoverSectionStyles = !disabled && {
    backgroundColor: hoveredActiveSectionColor,
    selectors: _defineProperty({}, HighContrastSelector, {
      backgroundColor: 'Highlight'
    })
  };
  var slideBoxActiveThumbStyles = !disabled && {
    border: "2px solid ".concat(pressedActiveSectionColor),
    selectors: _defineProperty({}, HighContrastSelector, {
      borderColor: 'Highlight'
    })
  };
  var slideBoxActiveZeroTickStyles = !props.disabled && {
    backgroundColor: semanticColors.inputPlaceholderBackgroundChecked,
    selectors: _defineProperty({}, HighContrastSelector, {
      backgroundColor: 'Highlight'
    })
  };
  return {
    root: [classNames.root, {
      userSelect: 'none'
    }, vertical && {
      marginRight: 8
    }].concat([!disabled ? classNames.enabled : undefined], [disabled ? classNames.disabled : undefined], [!vertical ? classNames.row : undefined], [vertical ? classNames.column : undefined], [className]),
    titleLabel: [{
      padding: 0
    }, titleLabelClassName],
    container: [classNames.container, {
      display: 'flex',
      flexWrap: 'nowrap',
      alignItems: 'center'
    }, vertical && {
      flexDirection: 'column',
      height: '100%',
      textAlign: 'center',
      margin: '8px 0'
    }],
    slideBox: [classNames.slideBox, getFocusStyle(theme), {
      background: 'transparent',
      border: 'none',
      flexGrow: 1,
      lineHeight: 28,
      display: 'flex',
      alignItems: 'center',
      selectors: (_selectors6 = {}, _defineProperty(_selectors6, ":active .".concat(classNames.activeSection), slideBoxActiveSectionStyles), _defineProperty(_selectors6, ":hover .".concat(classNames.activeSection), slideHoverSectionStyles), _defineProperty(_selectors6, ":active .".concat(classNames.inactiveSection), slideBoxInactiveSectionStyles), _defineProperty(_selectors6, ":hover .".concat(classNames.inactiveSection), slideBoxInactiveSectionStyles), _defineProperty(_selectors6, ":active .".concat(classNames.thumb), slideBoxActiveThumbStyles), _defineProperty(_selectors6, ":hover .".concat(classNames.thumb), slideBoxActiveThumbStyles), _defineProperty(_selectors6, ":active .".concat(classNames.zeroTick), slideBoxActiveZeroTickStyles), _defineProperty(_selectors6, ":hover .".concat(classNames.zeroTick), slideBoxActiveZeroTickStyles), _selectors6)
    }, vertical ? {
      height: '100%',
      width: 28,
      padding: '8px 0'
    } : {
      height: 28,
      width: 'auto',
      padding: '0 8px'
    }].concat([showValue ? classNames.showValue : undefined], [showTransitions ? classNames.showTransitions : undefined]),
    thumb: [classNames.thumb, {
      borderWidth: 2,
      borderStyle: 'solid',
      borderColor: thumbBorderColor,
      borderRadius: 10,
      boxSizing: 'border-box',
      background: thumbBackgroundColor,
      display: 'block',
      width: 16,
      height: 16,
      position: 'absolute'
    }, vertical ? {
      left: -6,
      margin: '0 auto',
      transform: 'translateY(8px)'
    } : {
      top: -6,
      transform: getRTL() ? 'translateX(50%)' : 'translateX(-50%)'
    }, showTransitions && {
      transition: "left ".concat(AnimationVariables.durationValue3, " ").concat(AnimationVariables.easeFunction1)
    }, disabled && {
      borderColor: thumbDisabledBorderColor,
      selectors: _defineProperty({}, HighContrastSelector, {
        borderColor: 'GrayText'
      })
    }],
    line: [classNames.line, {
      display: 'flex',
      position: 'relative'
    }, vertical ? {
      height: '100%',
      width: 4,
      margin: '0 auto',
      flexDirection: 'column-reverse'
    } : {
      width: '100%'
    }],
    lineContainer: [{
      borderRadius: 4,
      boxSizing: 'border-box'
    }, vertical ? {
      width: 4,
      height: '100%'
    } : {
      height: 4,
      width: '100%'
    }],
    activeSection: [classNames.activeSection, {
      background: restActiveSectionColor,
      selectors: _defineProperty({}, HighContrastSelector, {
        backgroundColor: 'WindowText'
      })
    }, showTransitions && {
      transition: "width ".concat(AnimationVariables.durationValue3, " ").concat(AnimationVariables.easeFunction1)
    }, disabled && {
      background: disabledActiveSectionColor,
      selectors: _defineProperty({}, HighContrastSelector, {
        backgroundColor: 'GrayText',
        borderColor: 'GrayText'
      })
    }],
    inactiveSection: [classNames.inactiveSection, {
      background: restInactiveSectionColor,
      selectors: _defineProperty({}, HighContrastSelector, {
        border: '1px solid WindowText'
      })
    }, showTransitions && {
      transition: "width ".concat(AnimationVariables.durationValue3, " ").concat(AnimationVariables.easeFunction1)
    }, disabled && {
      background: disabledInactiveSectionColor,
      selectors: _defineProperty({}, HighContrastSelector, {
        borderColor: 'GrayText'
      })
    }],
    zeroTick: [classNames.zeroTick, {
      position: 'absolute',
      background: semanticColors.disabledBorder,
      selectors: _defineProperty({}, HighContrastSelector, {
        backgroundColor: 'WindowText'
      })
    }, props.disabled && {
      background: semanticColors.disabledBackground,
      selectors: _defineProperty({}, HighContrastSelector, {
        backgroundColor: 'GrayText'
      })
    }, props.vertical ? {
      width: '16px',
      height: '1px',
      transform: getRTL() ? 'translateX(6px)' : 'translateX(-6px)'
    } : {
      width: '1px',
      height: '16px',
      transform: 'translateY(-6px)'
    }],
    valueLabel: [classNames.valueLabel, {
      flexShrink: 1,
      width: 30,
      lineHeight: '1'
    }, vertical ? {
      margin: '0 auto',
      whiteSpace: 'nowrap',
      width: 40
    } : {
      margin: '0 8px',
      whiteSpace: 'nowrap',
      width: 40
    }]
  };
};

export { getStyles };
