import { memoizeFunction } from '@uifabric-vue/utilities';
import { mergeStyles } from '@uifabric/styling';
import { Position } from '../../utilities/positioning/positioning.types.js';
import '../../utilities/positioning/positioning.js';

var getClassNames = memoizeFunction(function (styles, disabled, isFocused, keyboardSpinDirection) {
  var labelPosition = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : Position.start;
  var className = arguments.length > 5 && arguments[5] !== undefined ? arguments[5] : undefined;
  return {
    root: mergeStyles(styles.root, className),
    labelWrapper: mergeStyles(styles.labelWrapper, _getStyleForLabelBasedOnPosition(labelPosition, styles)),
    icon: mergeStyles(styles.icon, disabled && styles.iconDisabled),
    label: mergeStyles(styles.label),
    spinButtonWrapper: mergeStyles(styles.spinButtonWrapper, _getStyleForRootBasedOnPosition(labelPosition, styles), !disabled && [{
      selectors: {
        ':hover': styles.spinButtonWrapperHovered
      }
    }, isFocused && {
      selectors: {
        '&&': styles.spinButtonWrapperFocused
      }
    }], disabled && styles.spinButtonWrapperDisabled),
    input: mergeStyles('ms-spinButton-input', styles.input, !disabled && {
      selectors: {
        '::selection': styles.inputTextSelected
      }
    }, disabled && styles.inputDisabled),
    arrowBox: mergeStyles(styles.arrowButtonsContainer, disabled && styles.arrowButtonsContainerDisabled)
  };
});

function _getStyleForLabelBasedOnPosition(labelPosition, styles) {
  switch (labelPosition) {
    case Position.start:
      return styles.labelWrapperStart;

    case Position.end:
      return styles.labelWrapperEnd;

    case Position.top:
      return styles.labelWrapperTop;

    case Position.bottom:
      return styles.labelWrapperBottom;
  }
}

function _getStyleForRootBasedOnPosition(labelPosition, styles) {
  switch (labelPosition) {
    case Position.top:
    case Position.bottom:
      return styles.spinButtonWrapperTopBottom;

    default:
      return {};
  }
}

export { getClassNames };
