import '../node_modules/core-js/modules/es.array.concat.js';
import { memoizeFunction } from '@uifabric-vue/utilities';
import { HighContrastSelector, IconFontSizes } from '@uifabric/styling';
import _defineProperty from '@babel/runtime/helpers/defineProperty';
import { concatStyleSets } from '@uifabric/merge-styles';

var ARROW_BUTTON_WIDTH = 23;
var ARROW_BUTTON_ICON_SIZE = 8;
var DEFAULT_HEIGHT = 32;
var DEFAULT_MIN_WIDTH = 86;
var LABEL_MARGIN = 10;

var _getDisabledStyles = memoizeFunction(function (theme) {
  var semanticColors = theme.semanticColors;
  var SpinButtonTextColorDisabled = semanticColors.disabledText;
  var SpinButtonBackgroundColorDisabled = semanticColors.disabledBackground;
  return {
    backgroundColor: SpinButtonBackgroundColorDisabled,
    borderColor: SpinButtonBackgroundColorDisabled,
    pointerEvents: 'none',
    cursor: 'default',
    color: SpinButtonTextColorDisabled,
    selectors: _defineProperty({}, HighContrastSelector, {
      color: 'GrayText'
    })
  };
});

var getArrowButtonStyles = memoizeFunction(function (theme, isUpArrow, customSpecificArrowStyles) {
  var palette = theme.palette,
      effects = theme.effects;
  var ArrowButtonTextColor = palette.neutralSecondary;
  var ArrowButtonTextColorHovered = palette.neutralPrimary;
  var ArrowButtonTextColorPressed = palette.neutralPrimary;
  var ArrowButtonBackgroundHovered = palette.neutralLighter;
  var ArrowButtonBackgroundPressed = palette.neutralLight;
  var defaultArrowButtonStyles = {
    root: {
      outline: 'none',
      display: 'block',
      height: '50%',
      width: ARROW_BUTTON_WIDTH,
      padding: 0,
      backgroundColor: 'transparent',
      textAlign: 'center',
      cursor: 'default',
      color: ArrowButtonTextColor,
      selectors: {
        '&.ms-DownButton': {
          borderRadius: "0 0 ".concat(effects.roundedCorner2, " 0")
        },
        '&.ms-UpButton': {
          borderRadius: "0 ".concat(effects.roundedCorner2, " 0 0")
        }
      }
    },
    rootHovered: {
      backgroundColor: ArrowButtonBackgroundHovered,
      color: ArrowButtonTextColorHovered
    },
    rootChecked: {
      backgroundColor: ArrowButtonBackgroundPressed,
      color: ArrowButtonTextColorPressed,
      selectors: _defineProperty({}, HighContrastSelector, {
        backgroundColor: 'Highlight',
        color: 'HighlightText'
      })
    },
    rootPressed: {
      backgroundColor: ArrowButtonBackgroundPressed,
      color: ArrowButtonTextColorPressed,
      selectors: _defineProperty({}, HighContrastSelector, {
        backgroundColor: 'Highlight',
        color: 'HighlightText'
      })
    },
    rootDisabled: {
      opacity: 0.5,
      selectors: _defineProperty({}, HighContrastSelector, {
        color: 'GrayText',
        opacity: 1
      })
    },
    icon: {
      fontSize: ARROW_BUTTON_ICON_SIZE,
      marginTop: 0,
      marginRight: 0,
      marginBottom: 0,
      marginLeft: 0
    }
  };
  var defaultUpArrowButtonStyles = {};
  var defaultDownArrowButtonStyles = {};
  return concatStyleSets(defaultArrowButtonStyles, isUpArrow ? defaultUpArrowButtonStyles : defaultDownArrowButtonStyles, customSpecificArrowStyles);
});
var getStyles = memoizeFunction(function (theme, customStyles) {
  var _selectors6;

  var palette = theme.palette,
      semanticColors = theme.semanticColors,
      effects = theme.effects,
      fonts = theme.fonts;
  var SpinButtonRootBorderColor = semanticColors.inputBorder;
  var SpinButtonRootBorderColorHovered = semanticColors.inputBorderHovered;
  var SpinButtonRootBorderColorFocused = semanticColors.inputFocusBorderAlt;
  var SpinButtonInputTextColor = semanticColors.bodyText;
  var SpinButtonInputTextColorSelected = palette.white;
  var SpinButtonInputBackgroundColorSelected = palette.themePrimary;
  var SpinButtonIconDisabledColor = semanticColors.disabledText;
  var defaultStyles = {
    root: {
      outline: 'none',
      fontSize: fonts.medium.fontSize,
      width: '100%',
      minWidth: DEFAULT_MIN_WIDTH
    },
    labelWrapper: {
      display: 'inline-flex',
      alignItems: 'center'
    },
    labelWrapperStart: {
      height: DEFAULT_HEIGHT,
      "float": 'left',
      marginRight: LABEL_MARGIN
    },
    labelWrapperEnd: {
      height: DEFAULT_HEIGHT,
      "float": 'right',
      marginLeft: LABEL_MARGIN
    },
    labelWrapperTop: {
      marginBottom: -1
    },
    labelWrapperBottom: {},
    icon: {
      padding: '0 5px',
      fontSize: IconFontSizes.large
    },
    iconDisabled: {
      color: SpinButtonIconDisabledColor
    },
    label: {
      pointerEvents: 'none',
      lineHeight: IconFontSizes.large
    },
    labelDisabled: {},
    spinButtonWrapper: {
      display: 'flex',
      position: 'relative',
      boxSizing: 'border-box',
      height: DEFAULT_HEIGHT,
      minWidth: DEFAULT_MIN_WIDTH,
      border: "1px solid ".concat(SpinButtonRootBorderColor),
      borderRadius: effects.roundedCorner2
    },
    spinButtonWrapperTopBottom: {
      width: '100%'
    },
    spinButtonWrapperHovered: {
      borderColor: SpinButtonRootBorderColorHovered,
      selectors: _defineProperty({}, HighContrastSelector, {
        borderColor: 'Highlight'
      })
    },
    spinButtonWrapperFocused: {
      selectors: (_selectors6 = {}, _defineProperty(_selectors6, HighContrastSelector, {
        borderColor: 'Highlight'
      }), _defineProperty(_selectors6, ':after', {
        pointerEvents: 'none',
        content: "''",
        position: 'absolute',
        left: -1,
        top: -1,
        bottom: -1,
        right: -1,
        border: "2px solid ".concat(SpinButtonRootBorderColorFocused),
        borderRadius: effects.roundedCorner2
      }), _selectors6)
    },
    spinButtonWrapperDisabled: _getDisabledStyles(theme),
    input: {
      boxSizing: 'border-box',
      boxShadow: 'none',
      borderStyle: 'none',
      flex: 1,
      margin: 0,
      fontSize: fonts.medium.fontSize,
      color: SpinButtonInputTextColor,
      height: '100%',
      padding: '0 8px',
      outline: 0,
      display: 'block',
      minWidth: DEFAULT_MIN_WIDTH - ARROW_BUTTON_WIDTH - 2,
      whiteSpace: 'nowrap',
      textOverflow: 'ellipsis',
      overflow: 'hidden',
      cursor: 'text',
      userSelect: 'text',
      borderRadius: "".concat(effects.roundedCorner2, " 0 0 ").concat(effects.roundedCorner2)
    },
    inputTextSelected: {
      backgroundColor: SpinButtonInputBackgroundColorSelected,
      color: SpinButtonInputTextColorSelected,
      selectors: _defineProperty({}, HighContrastSelector, {
        backgroundColor: 'Highlight',
        borderColor: 'Highlight',
        color: 'HighlightText'
      })
    },
    inputDisabled: _getDisabledStyles(theme),
    arrowButtonsContainer: {
      display: 'block',
      height: '100%',
      cursor: 'default'
    },
    arrowButtonsContainerDisabled: _getDisabledStyles(theme)
  };
  return concatStyleSets(defaultStyles, customStyles);
});

export { getArrowButtonStyles, getStyles };
