import { HighContrastSelector, getFocusStyle, FontWeights } from '@uifabric/styling';
import _defineProperty from '@babel/runtime/helpers/defineProperty';

var DEFAULT_PILL_WIDTH = 40;
var DEFAULT_PILL_HEIGHT = 20;
var DEFAULT_THUMB_SIZE = 12;
var getStyles = function getStyles(props) {
  var theme = props.theme,
      className = props.className,
      disabled = props.disabled,
      checked = props.checked,
      inlineLabel = props.inlineLabel,
      onOffMissing = props.onOffMissing;
  var semanticColors = theme.semanticColors,
      palette = theme.palette;
  var pillUncheckedBackground = semanticColors.bodyBackground;
  var pillCheckedBackground = semanticColors.inputBackgroundChecked;
  var pillCheckedHoveredBackground = palette.themeDark;
  var thumbUncheckedHoveredBackground = palette.neutralDark;
  var pillCheckedDisabledBackground = semanticColors.disabledBodySubtext;
  var thumbBackground = semanticColors.smallInputBorder;
  var thumbCheckedBackground = semanticColors.inputForegroundChecked;
  var thumbDisabledBackground = semanticColors.disabledBodySubtext;
  var thumbCheckedDisabledBackground = semanticColors.disabledBackground;
  var pillBorderColor = semanticColors.smallInputBorder;
  var pillBorderHoveredColor = semanticColors.inputBorderHovered;
  var pillBorderDisabledColor = semanticColors.disabledBodySubtext;
  var textDisabledColor = semanticColors.disabledText;
  return {
    root: ['ms-Toggle', checked && 'is-checked', !disabled && 'is-enabled', disabled && 'is-disabled', theme.fonts.medium, {
      marginBottom: '8px'
    }, inlineLabel && {
      display: 'flex',
      alignItems: 'center'
    }, className],
    label: ['ms-Toggle-label', disabled && {
      color: textDisabledColor,
      selectors: _defineProperty({}, HighContrastSelector, {
        color: 'GrayText'
      })
    }, inlineLabel && !onOffMissing && {
      marginRight: 16
    }, onOffMissing && inlineLabel && {
      order: 1,
      marginLeft: 16
    }, inlineLabel && {
      wordBreak: 'break-all'
    }],
    container: ['ms-Toggle-innerContainer', {
      display: 'inline-flex',
      position: 'relative'
    }],
    pill: ['ms-Toggle-background', getFocusStyle(theme, {
      inset: -3
    }), {
      fontSize: '20px',
      boxSizing: 'border-box',
      width: DEFAULT_PILL_WIDTH,
      height: DEFAULT_PILL_HEIGHT,
      borderRadius: DEFAULT_PILL_HEIGHT / 2,
      transition: 'all 0.1s ease',
      border: "1px solid ".concat(pillBorderColor),
      background: pillUncheckedBackground,
      cursor: 'pointer',
      display: 'flex',
      alignItems: 'center',
      padding: '0 3px'
    }, !disabled && [!checked && {
      selectors: {
        ':hover': [{
          borderColor: pillBorderHoveredColor
        }],
        ':hover .ms-Toggle-thumb': [{
          backgroundColor: thumbUncheckedHoveredBackground,
          selectors: _defineProperty({}, HighContrastSelector, {
            borderColor: 'Highlight'
          })
        }]
      }
    }, checked && [{
      background: pillCheckedBackground,
      borderColor: 'transparent',
      justifyContent: 'flex-end'
    }, {
      selectors: _defineProperty({
        ':hover': [{
          backgroundColor: pillCheckedHoveredBackground,
          borderColor: 'transparent',
          selectors: _defineProperty({}, HighContrastSelector, {
            backgroundColor: 'Highlight'
          })
        }]
      }, HighContrastSelector, {
        backgroundColor: 'WindowText'
      })
    }]], disabled && [{
      cursor: 'default'
    }, !checked && [{
      borderColor: pillBorderDisabledColor
    }], checked && [{
      backgroundColor: pillCheckedDisabledBackground,
      borderColor: 'transparent',
      justifyContent: 'flex-end'
    }]], !disabled && {
      selectors: {
        '&:hover': {
          selectors: _defineProperty({}, HighContrastSelector, {
            borderColor: 'Highlight'
          })
        }
      }
    }],
    thumb: ['ms-Toggle-thumb', {
      width: DEFAULT_THUMB_SIZE,
      height: DEFAULT_THUMB_SIZE,
      borderRadius: '50%',
      transition: 'all 0.1s ease',
      backgroundColor: thumbBackground,
      borderColor: 'transparent',
      borderWidth: '.28em',
      borderStyle: 'solid',
      boxSizing: 'border-box'
    }, !disabled && checked && [{
      backgroundColor: thumbCheckedBackground,
      selectors: _defineProperty({}, HighContrastSelector, {
        backgroundColor: 'Window',
        borderColor: 'Window'
      })
    }], disabled && [!checked && [{
      backgroundColor: thumbDisabledBackground
    }], checked && [{
      backgroundColor: thumbCheckedDisabledBackground
    }]]],
    text: ['ms-Toggle-stateText', {
      selectors: {
        '&&': {
          padding: '0',
          margin: '0 8px',
          userSelect: 'none',
          fontWeight: FontWeights.regular
        }
      }
    }, disabled && {
      selectors: {
        '&&': {
          color: textDisabledColor,
          selectors: _defineProperty({}, HighContrastSelector, {
            color: 'GrayText'
          })
        }
      }
    }]
  };
};

export { getStyles };
