import '../node_modules/core-js/modules/es.date.to-string.js';
import '../node_modules/core-js/modules/es.object.to-string.js';
import '../node_modules/core-js/modules/es.regexp.to-string.js';
import _classCallCheck from '@babel/runtime/helpers/classCallCheck';
import _createClass from '@babel/runtime/helpers/createClass';
import { EventGroup, getId } from '@uifabric-vue/utilities';
import '../node_modules/core-js/modules/es.symbol.js';
import '../node_modules/core-js/modules/es.array.filter.js';
import '../node_modules/core-js/modules/es.array.for-each.js';
import '../node_modules/core-js/modules/es.object.define-properties.js';
import '../node_modules/core-js/modules/es.object.define-property.js';
import '../node_modules/core-js/modules/es.object.get-own-property-descriptor.js';
import '../node_modules/core-js/modules/es.object.get-own-property-descriptors.js';
import '../node_modules/core-js/modules/es.object.keys.js';
import '../node_modules/core-js/modules/web.dom-collections.for-each.js';
import _defineProperty from '@babel/runtime/helpers/defineProperty';
import '../node_modules/core-js/modules/es.array.map.js';
import _toConsumableArray from '@babel/runtime/helpers/toConsumableArray';
import { KeytipEvents } from './KeytipConstants.js';

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }
var KeytipManager = function () {
  function KeytipManager() {
    _classCallCheck(this, KeytipManager);

    this.keytips = {};
    this.persistedKeytips = {};
    this.sequenceMapping = {};
    this.inKeytipMode = false;
    this.shouldEnterKeytipMode = true;
    this.delayUpdatingKeytipChange = false;
  }

  _createClass(KeytipManager, [{
    key: "init",
    value: function init(delayUpdatingKeytipChange) {
      this.delayUpdatingKeytipChange = delayUpdatingKeytipChange;
    }
  }, {
    key: "register",
    value: function register(keytipProps) {
      var persisted = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;
      var props = keytipProps;

      if (!persisted) {
        props = this.addParentOverflow(keytipProps);
        this.sequenceMapping[props.keySequences.toString()] = props;
      }

      var uniqueKeytip = this._getUniqueKtp(props);

      persisted ? this.persistedKeytips[uniqueKeytip.uniqueID] = uniqueKeytip : this.keytips[uniqueKeytip.uniqueID] = uniqueKeytip;

      if (this.inKeytipMode || !this.delayUpdatingKeytipChange) {
        var event = persisted ? KeytipEvents.PERSISTED_KEYTIP_ADDED : KeytipEvents.KEYTIP_ADDED;
        EventGroup.raise(this, event, {
          keytip: props,
          uniqueID: uniqueKeytip.uniqueID
        });
      }

      return uniqueKeytip.uniqueID;
    }
  }, {
    key: "update",
    value: function update(keytipProps, uniqueID) {
      var newKeytipProps = this.addParentOverflow(keytipProps);

      var uniqueKeytip = this._getUniqueKtp(newKeytipProps, uniqueID);

      var oldKeyTip = this.keytips[uniqueID];

      if (oldKeyTip) {
        uniqueKeytip.keytip.visible = oldKeyTip.keytip.visible;
        this.keytips[uniqueID] = uniqueKeytip;
        delete this.sequenceMapping[oldKeyTip.keytip.keySequences.toString()];
        this.sequenceMapping[uniqueKeytip.keytip.keySequences.toString()] = uniqueKeytip.keytip;

        if (this.inKeytipMode || !this.delayUpdatingKeytipChange) {
          EventGroup.raise(this, KeytipEvents.KEYTIP_UPDATED, {
            keytip: uniqueKeytip.keytip,
            uniqueID: uniqueKeytip.uniqueID
          });
        }
      }
    }
  }, {
    key: "unregister",
    value: function unregister(keytipToRemove, uniqueID) {
      var persisted = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : false;
      persisted ? delete this.persistedKeytips[uniqueID] : delete this.keytips[uniqueID];
      !persisted && delete this.sequenceMapping[keytipToRemove.keySequences.toString()];
      var event = persisted ? KeytipEvents.PERSISTED_KEYTIP_REMOVED : KeytipEvents.KEYTIP_REMOVED;

      if (this.inKeytipMode || !this.delayUpdatingKeytipChange) {
        EventGroup.raise(this, event, {
          keytip: keytipToRemove,
          uniqueID: uniqueID
        });
      }
    }
  }, {
    key: "enterKeytipMode",
    value: function enterKeytipMode() {
      EventGroup.raise(this, KeytipEvents.ENTER_KEYTIP_MODE);
    }
  }, {
    key: "exitKeytipMode",
    value: function exitKeytipMode() {
      EventGroup.raise(this, KeytipEvents.EXIT_KEYTIP_MODE);
    }
  }, {
    key: "getKeytips",
    value: function getKeytips() {
      var _this = this;

      return Object.keys(this.keytips).map(function (key) {
        return _this.keytips[key].keytip;
      });
    }
  }, {
    key: "addParentOverflow",
    value: function addParentOverflow(keytipProps) {
      var fullSequence = _toConsumableArray(keytipProps.keySequences);

      fullSequence.pop();

      if (fullSequence.length !== 0) {
        var parentKeytip = this.sequenceMapping[fullSequence.toString()];

        if (parentKeytip && parentKeytip.overflowSetSequence) {
          return _objectSpread(_objectSpread({}, keytipProps), {}, {
            overflowSetSequence: parentKeytip.overflowSetSequence
          });
        }
      }

      return keytipProps;
    }
  }, {
    key: "menuExecute",
    value: function menuExecute(overflowButtonSequences, keytipSequences) {
      EventGroup.raise(this, KeytipEvents.PERSISTED_KEYTIP_EXECUTE, {
        overflowButtonSequences: overflowButtonSequences,
        keytipSequences: keytipSequences
      });
    }
  }, {
    key: "_getUniqueKtp",
    value: function _getUniqueKtp(keytipProps) {
      var uniqueID = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : getId();
      return {
        keytip: _objectSpread({}, keytipProps),
        uniqueID: uniqueID
      };
    }
  }], [{
    key: "getInstance",
    value: function getInstance() {
      return this._instance;
    }
  }]);

  return KeytipManager;
}();
KeytipManager._instance = new KeytipManager();

export { KeytipManager };
