import { __decorate, __metadata } from "tslib";
import { Component, Prop } from 'vue-property-decorator';
import { isIE11, KeyCodes } from '@uifabric-vue/utilities';
import BaseComponent from '../BaseComponent';
const SELECTION_FORWARD = 'forward';
const SELECTION_BACKWARD = 'backward';
let Autofill = class Autofill extends BaseComponent {
    constructor() {
        super(...arguments);
        this.autoFillEnabled = false;
        this.isComposing = false;
        this.internalValue = this.defaultVisibleValue || '';
        this.displayValue = this.defaultVisibleValue || '';
    }
    get cursorLocation() {
        if (this.$refs.inputElement) {
            const inputElement = this.$refs.inputElement;
            if (inputElement.selectionDirection !== SELECTION_FORWARD) {
                return inputElement.selectionEnd;
            }
            else {
                return inputElement.selectionStart;
            }
        }
        else {
            return -1;
        }
    }
    get value() {
        return this.internalValue;
    }
    get isValueSelected() {
        return Boolean(this.$refs.inputElement && this.$refs.inputElement.selectionStart !== this.$refs.inputElement.selectionEnd);
    }
    get selectionStart() {
        return this.$refs.inputElement ? this.$refs.inputElement.selectionStart : -1;
    }
    get selectionEnd() {
        return this.$refs.inputElement ? this.$refs.inputElement.selectionEnd : -1;
    }
    focus() {
        this.$refs.inputElement && this.$refs.inputElement.focus();
    }
    clear() {
        this.autoFillEnabled = true;
        this.updateValue('', false);
        this.$refs.inputElement && this.$refs.inputElement.setSelectionRange(0, 0);
    }
    onKeyDown(ev) {
        this.$emit('keydown', ev);
        // If the event is actively being composed, then don't alert autofill.
        // Right now typing does not have isComposing, once that has been fixed any should be removed.
        if (!ev.isComposing) {
            switch (ev.which) {
                case KeyCodes.backspace:
                    this.autoFillEnabled = false;
                    break;
                case KeyCodes.left:
                case KeyCodes.right:
                    if (this.autoFillEnabled) {
                        this.internalValue = this.displayValue;
                        this.autoFillEnabled = false;
                    }
                    break;
                default:
                    if (!this.autoFillEnabled) {
                        if (this.enableAutofillOnKeyPress.indexOf(ev.which) !== -1) {
                            this.autoFillEnabled = true;
                        }
                    }
                    break;
            }
        }
    }
    ;
    onInputChanged(ev) {
        const value = this.getCurrentInputValue(ev);
        if (!this.isComposing) {
            this.tryEnableAutofill(value, this.value, ev.isComposing);
        }
        // If it is not IE11 and currently composing, update the value
        if (!(isIE11() && this.isComposing)) {
            const nativeEventComposing = ev.composed;
            const isComposing = nativeEventComposing === undefined ? this.isComposing : nativeEventComposing;
            this.updateValue(value, isComposing);
        }
    }
    ;
    getCurrentInputValue(ev) {
        if (ev && ev.target && ev.target.value) {
            return ev.target.value;
        }
        else if (this.$refs.inputElement && this.$refs.inputElement.value) {
            return this.$refs.inputElement.value;
        }
        else {
            return '';
        }
    }
    /**
     * Updates the current input value as well as getting a new display value.
     * @param newValue - The new value from the input
     */
    updateValue(newValue, composing) {
        // Only proceed if the value is nonempty and is different from the old value
        // This is to work around the fact that, in IE 11, inputs with a placeholder fire an onInput event on focus
        if (!newValue && newValue === this.value) {
            return;
        }
        this.internalValue = this.onInputChange ? this.onInputChange(newValue, composing) : newValue;
        this.displayValue = this.getDisplayValue(this.value, this.suggestedDisplayValue);
    }
    getDisplayValue(inputValue, suggestedDisplayValue) {
        let displayValue = inputValue;
        if (suggestedDisplayValue &&
            inputValue &&
            this.doesTextStartWith(suggestedDisplayValue, displayValue) &&
            this.autoFillEnabled) {
            displayValue = suggestedDisplayValue;
        }
        return displayValue;
    }
    doesTextStartWith(text, startWith) {
        if (!text || !startWith) {
            return false;
        }
        return text.toLocaleLowerCase().indexOf(startWith.toLocaleLowerCase()) === 0;
    }
    /**
     * Attempts to enable autofill. Whether or not autofill is enabled depends on the input value,
     * whether or not any text is selected, and only if the new input value is longer than the old input value.
     * Autofill should never be set to true if the value is composing. Once compositionEnd is called, then
     * it should be completed.
     * See https://developer.mozilla.org/en-US/docs/Web/API/CompositionEvent for more information on composition.
     * @param newValue - new input value
     * @param oldValue - old input value
     * @param isComposing - if true then the text is actively being composed and it has not completed.
     * @param isComposed - if the text is a composed text value.
     */
    tryEnableAutofill(newValue, oldValue, isComposing, isComposed) {
        if (!isComposing &&
            newValue &&
            this.$refs.inputElement &&
            this.$refs.inputElement.selectionStart === newValue.length &&
            !this.autoFillEnabled &&
            (newValue.length > oldValue.length || isComposed)) {
            this.autoFillEnabled = true;
        }
    }
    render() {
        const { displayValue } = this;
        return (<input ref="inputElement" 
        // @ts-ignore
        autoCapitalize="off" autoComplete="off" aria-autocomplete={'both'} 
        // {...nativeProps}
        value={displayValue} 
        // onCompositionStart={this._onCompositionStart}
        // onCompositionUpdate={this._onCompositionUpdate}
        // onCompositionEnd={this._onCompositionEnd}
        onInput={this.onInputChanged} onKeydown={this.onKeyDown} onClick={ev => this.$emit('click', ev)} data-lpignore={true}/>);
    }
};
__decorate([
    Prop({ type: String, default: '' }),
    __metadata("design:type", String)
], Autofill.prototype, "defaultVisibleValue", void 0);
__decorate([
    Prop({ type: String, default: '' }),
    __metadata("design:type", String)
], Autofill.prototype, "suggestedDisplayValue", void 0);
__decorate([
    Prop({ type: Boolean, default: false }),
    __metadata("design:type", Boolean)
], Autofill.prototype, "preventValueSelection", void 0);
__decorate([
    Prop({ type: Array, default: () => [KeyCodes.down, KeyCodes.up] }),
    __metadata("design:type", Array)
], Autofill.prototype, "enableAutofillOnKeyPress", void 0);
__decorate([
    Prop({ type: Function, default: null }),
    __metadata("design:type", Function)
], Autofill.prototype, "onInputChange", void 0);
__decorate([
    Prop({ type: Function, default: null }),
    __metadata("design:type", Function)
], Autofill.prototype, "onInputValueChange", void 0);
Autofill = __decorate([
    Component
], Autofill);
export { Autofill };
//# sourceMappingURL=Autofill.jsx.map