import { __decorate, __metadata } from "tslib";
import { Vue, Prop, Component } from 'vue-property-decorator';
import { css, Async, EventGroup } from '@uifabric-vue/utilities';
import { getTheme } from '@uifabric/styling';
// @ts-ignore
let BaseComponent = class BaseComponent extends Vue {
    constructor() {
        super(...arguments);
        this.componentRef = null;
        this.css = css;
        this.__async = null;
        this.__events = null;
        this.__disposables = null;
        this.state = {};
        this.props = {};
    }
    // created () {
    //   for (const key in this.$props) {
    //     if (this.$props.hasOwnProperty(key)) {
    //       this.$set(this.props as any, key, this.$props[key])
    //     }
    //   }
    // }
    /**
     * When the component has mounted, update the componentRef.
     */
    mounted() {
        this.componentRef = this.$el;
    }
    /**
     * If we have disposables, dispose them automatically on unmount.
     */
    beforeDestroy() {
        if (this.__disposables) {
            for (let i = 0, len = this._disposables.length; i < len; i++) {
                const disposable = this.__disposables[i];
                if (disposable.dispose) {
                    disposable.dispose();
                }
            }
            this.__disposables = null;
        }
    }
    get uid() {
        // @ts-ignore
        return this._uid;
    }
    get classNames() {
        return {};
    }
    /**
     * Allows subclasses to push things to this._disposables to be auto disposed.
     */
    get _disposables() {
        if (!this.__disposables) {
            this.__disposables = [];
        }
        return this.__disposables;
    }
    /**
     * Gets the async instance associated with the component, created on demand. The async instance gives
     * subclasses a way to execute setTimeout/setInterval async calls safely, where the callbacks
     * will be cleared/ignored automatically after unmounting. The helpers within the async object also
     * preserve the this pointer so that you don't need to "bind" the callbacks.
     */
    get _async() {
        if (!this.__async) {
            this.__async = new Async(this);
            this._disposables.push(this.__async);
        }
        return this.__async;
    }
    /**
     * Gets the event group instance assocaited with the component, created on demand. The event instance
     * provides on/off methods for listening to DOM (or regular javascript object) events. The event callbacks
     * will be automatically disconnected after unmounting. The helpers within the events object also
     * preserve the this reference so that you don't need to "bind" the callbacks.
     */
    get events() {
        if (!this.__events) {
            this.__events = new EventGroup(this);
            this._disposables.push(this.__events);
        }
        return this.__events;
    }
    /**
     * Updates the component's current state.
     *
     * @returns The updated state object.
     */
    setState(newState) {
        for (const key in newState) {
            this.$set(this.state, key, newState[key]);
        }
        return this.state;
    }
};
__decorate([
    Prop({ type: [String, Array], default: '' }),
    __metadata("design:type", String)
], BaseComponent.prototype, "className", void 0);
__decorate([
    Prop({ type: [Object, Function], default: () => { } }),
    __metadata("design:type", Object)
], BaseComponent.prototype, "styles", void 0);
__decorate([
    Prop({ type: Object, default: () => getTheme() }),
    __metadata("design:type", Object)
], BaseComponent.prototype, "theme", void 0);
BaseComponent = __decorate([
    Component
], BaseComponent);
export default BaseComponent;
//# sourceMappingURL=BaseComponent.js.map