import { __decorate, __metadata } from "tslib";
import { Component, Prop } from 'vue-property-decorator';
import BaseComponent from '../BaseComponent';
import { getStyles } from './Breadcrumb.styles';
import { classNamesFunction } from '@uifabric-vue/utilities';
import { Link } from '../Link';
import { Icon } from '../Icon';
const getClassNames = classNamesFunction();
let BreadcrumbBase = class BreadcrumbBase extends BaseComponent {
    get classNames() {
        const { className, theme } = this;
        return getClassNames(getStyles, {
            theme,
            className,
        });
    }
    onBreadcrumbClicked(event, item) {
        if (item.onClick) {
            item.onClick(event, item);
        }
    }
    render() {
        const { classNames, items } = this;
        return (<div class={classNames.root} role="navigation">
        <ol class={classNames.list}>
          {items.map((item, index) => (<li key={index} class={classNames.listItem}>
              {(item.onClick || item.href)
            ? (<Link class={classNames.itemLink} href={item.href} onClick={ev => this.onBreadcrumbClicked(ev, item)}>
                    {item.text}
                  </Link>)
            : (<span class={classNames.item} onClick={ev => this.onBreadcrumbClicked(ev, item)}>
                    {item.text}
                  </span>)}

              {(index !== (items.length - 1)) && (<Icon key={`icon-${index}`} class={classNames.chevron} icon-name="ChevronRight"/>)}
            </li>))}
        </ol>
      </div>);
    }
};
__decorate([
    Prop({ type: Array, required: true }),
    __metadata("design:type", Array)
], BreadcrumbBase.prototype, "items", void 0);
BreadcrumbBase = __decorate([
    Component
], BreadcrumbBase);
export { BreadcrumbBase };
//# sourceMappingURL=Breadcrumb.base.jsx.map