import { __decorate, __metadata } from "tslib";
import { Component, Prop, Watch, Model } from 'vue-property-decorator';
import { Label } from '../Label';
import { Icon } from '../Icon';
import BaseComponent from '../BaseComponent';
import { classNamesFunction } from '@uifabric-vue/utilities';
const getClassNames = classNamesFunction();
let CheckboxBase = class CheckboxBase extends BaseComponent {
    constructor() {
        super(...arguments);
        this.internalValue = this.checked || this.defaultChecked;
        this.isIndeterminate = this.indeterminate || this.defaultIndeterminate;
    }
    render() {
        const { classNames, title, label } = this;
        return (<div class={classNames.root}>
        <input id={`Checkbox${this.uid}`} class={classNames.input} {...this.$attrs} disabled={this.disabled} type="checkbox" onInput={this.onInput}/>

        <Label class={classNames.label} for={`Checkbox${this.uid}`}>
          <div class={classNames.checkbox}>
            <Icon icon-name="CheckMark" class={classNames.checkmark}/>
          </div>

          {(label || this.$slots.default) && (<span class={classNames.text} title={title}>
              {this.$slots.default || label}
            </span>)}
        </Label>
      </div>);
    }
    get classNames() {
        const { theme, className, disabled, isIndeterminate, internalValue, boxSide } = this;
        return getClassNames(this.styles, {
            theme,
            className,
            disabled,
            indeterminate: isIndeterminate,
            checked: internalValue,
            reversed: boxSide !== 'start',
            isUsingCustomLabelRender: true,
        });
    }
    onValueChanged(value) {
        this.$emit('input', value);
    }
    onInput() {
        if (this.disabled)
            return;
        if (this.isIndeterminate) {
            this.internalValue = this.defaultChecked;
            this.isIndeterminate = false;
        }
        else {
            this.internalValue = !this.internalValue;
        }
    }
};
__decorate([
    Model('input', { type: Boolean, default: false }),
    __metadata("design:type", Boolean)
], CheckboxBase.prototype, "checked", void 0);
__decorate([
    Prop({ type: Boolean, default: false }),
    __metadata("design:type", Boolean)
], CheckboxBase.prototype, "defaultChecked", void 0);
__decorate([
    Prop({ type: Boolean, default: false }),
    __metadata("design:type", Boolean)
], CheckboxBase.prototype, "indeterminate", void 0);
__decorate([
    Prop({ type: Boolean, default: false }),
    __metadata("design:type", Boolean)
], CheckboxBase.prototype, "defaultIndeterminate", void 0);
__decorate([
    Prop({ type: Boolean, default: false }),
    __metadata("design:type", Boolean)
], CheckboxBase.prototype, "disabled", void 0);
__decorate([
    Prop({ type: Boolean, default: false }),
    __metadata("design:type", Boolean)
], CheckboxBase.prototype, "required", void 0);
__decorate([
    Prop({ type: String, default: null }),
    __metadata("design:type", String)
], CheckboxBase.prototype, "label", void 0);
__decorate([
    Prop({ type: String, default: null }),
    __metadata("design:type", String)
], CheckboxBase.prototype, "title", void 0);
__decorate([
    Prop({ type: String, default: 'start', validator: v => ['start', 'end'].indexOf(v) > -1 }),
    __metadata("design:type", String)
], CheckboxBase.prototype, "boxSide", void 0);
__decorate([
    Watch('internalValue'),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Boolean]),
    __metadata("design:returntype", void 0)
], CheckboxBase.prototype, "onValueChanged", null);
CheckboxBase = __decorate([
    Component
], CheckboxBase);
export { CheckboxBase };
//# sourceMappingURL=Checkbox.base.jsx.map