import { __decorate, __metadata } from "tslib";
import { Component, Prop } from 'vue-property-decorator';
import BaseComponent from '../../BaseComponent';
import { classNamesFunction } from '@uifabric-vue/utilities';
import { Icon } from '../../Icon';
import { Image } from '../../Image';
const getClassNames = classNamesFunction();
let ChoiceGroupOptionBase = class ChoiceGroupOptionBase extends BaseComponent {
    get classNames() {
        const { styles, theme, iconProps, imageSrc, checked, disabled, imageSize, focused } = this;
        return getClassNames(styles, {
            theme: theme,
            hasIcon: !!iconProps,
            hasImage: !!imageSrc,
            checked,
            disabled,
            imageIsLarge: !!imageSrc && (imageSize.width > 71 || imageSize.height > 71),
            imageSize,
            focused,
        });
    }
    render() {
        const { id, classNames, text, imageSrc, imageAlt, imageSize, selectedImageSrc, iconProps, disabled } = this;
        return (<div class={classNames.root}>
        <div class={classNames.choiceFieldWrapper}>
          <input id={`ChoiceGroup${this.uid}-${id}`} name={`ChoiceGroup${this.uid}`} class={classNames.input} disabled={this.disabled} type="radio"/>

          <label for={`ChoiceGroup${this.uid}-${id}`} class={classNames.field}>
            {imageSrc && (<div class={classNames.innerField}>
                <div class={classNames.imageWrapper}>
                  <Image src={imageSrc} alt={imageAlt} width={imageSize.width} height={imageSize.height}/>
                </div>
                <div class={classNames.selectedImageWrapper}>
                  <Image src={selectedImageSrc} alt={imageAlt} width={imageSize.width} height={imageSize.height}/>
                </div>
              </div>)}
            {iconProps && (<div class={classNames.innerField}>
                <div class={classNames.iconWrapper}>
                  <Icon {...{ props: iconProps }}/>
                </div>
              </div>)}

            {(imageSrc || iconProps) ? (<div class={classNames.labelWrapper}>
                <span class="ms-ChoiceFieldLabel">
                  {this.$slots.default || text}
                </span>
              </div>) : (<span class="ms-ChoiceFieldLabel">
                {this.$slots.default || text}
              </span>)}
          </label>
        </div>
      </div>);
    }
};
__decorate([
    Prop(),
    __metadata("design:type", String)
], ChoiceGroupOptionBase.prototype, "id", void 0);
__decorate([
    Prop(),
    __metadata("design:type", String)
], ChoiceGroupOptionBase.prototype, "text", void 0);
__decorate([
    Prop(),
    __metadata("design:type", Object)
], ChoiceGroupOptionBase.prototype, "iconProps", void 0);
__decorate([
    Prop(),
    __metadata("design:type", Object)
], ChoiceGroupOptionBase.prototype, "imageSrc", void 0);
__decorate([
    Prop(),
    __metadata("design:type", Object)
], ChoiceGroupOptionBase.prototype, "selectedImageSrc", void 0);
__decorate([
    Prop(),
    __metadata("design:type", Object)
], ChoiceGroupOptionBase.prototype, "imageAlt", void 0);
__decorate([
    Prop(),
    __metadata("design:type", Boolean)
], ChoiceGroupOptionBase.prototype, "checked", void 0);
__decorate([
    Prop(),
    __metadata("design:type", Boolean)
], ChoiceGroupOptionBase.prototype, "disabled", void 0);
__decorate([
    Prop({ default: () => ({ width: 32, height: 32 }) }),
    __metadata("design:type", Object)
], ChoiceGroupOptionBase.prototype, "imageSize", void 0);
__decorate([
    Prop(),
    __metadata("design:type", Boolean)
], ChoiceGroupOptionBase.prototype, "focused", void 0);
ChoiceGroupOptionBase = __decorate([
    Component
], ChoiceGroupOptionBase);
export { ChoiceGroupOptionBase };
//# sourceMappingURL=ChoiceGroupOption.base.jsx.map