import { __decorate, __metadata } from "tslib";
import { ResizeObserver } from 'resize-observer';
import { Component, Prop } from 'vue-property-decorator';
import { css } from '@uifabric-vue/utilities';
import { getStyles } from './ComboBox.styles';
import BaseComponent from '../BaseComponent';
import { Label } from '../Label/';
import { IconButton, ActionButton } from '../Button';
import { Autofill } from '../Autofill/';
import VNodes from '../VNodes';
import { getClassNames } from './ComboBox.classNames';
import { Callout } from '../Callout';
import { Checkbox } from '../Checkbox';
var SearchDirection;
(function (SearchDirection) {
    SearchDirection[SearchDirection["backward"] = -1] = "backward";
    SearchDirection[SearchDirection["none"] = 0] = "none";
    SearchDirection[SearchDirection["forward"] = 1] = "forward";
})(SearchDirection || (SearchDirection = {}));
var HoverStatus;
(function (HoverStatus) {
    /** Used when the user was hovering and has since moused out of the menu items */
    HoverStatus[HoverStatus["clearAll"] = -2] = "clearAll";
    /** Default "normal" state, when no hover has happened or a hover is in progress */
    HoverStatus[HoverStatus["default"] = -1] = "default";
})(HoverStatus || (HoverStatus = {}));
const ScrollIdleDelay = 250; /* ms */
const TouchIdleDelay = 500; /* ms */
/**
 * This is used to clear any pending autocomplete text (used when autocomplete is true and
 * allowFreeform is false)
 */
const ReadOnlyPendingAutoCompleteTimeout = 1000; /* ms */
let ComboBoxBase = class ComboBoxBase extends BaseComponent {
    constructor() {
        super(...arguments);
        this.state = {
            isOpen: false,
            selectedIndices: [],
            focused: false,
            suggestedDisplayValue: '',
            currentOptions: [],
            currentPendingValueValidIndex: 0,
            currentPendingValueValidIndexOnHover: 0,
            currentPendingValue: '',
        };
        this.comboBoxMenuWidth = 0;
    }
    mounted() {
        const cb = this._async.throttle(() => {
            if (!this.$refs.comboBoxWrapper)
                return;
            /** Update `comboBoxMenuWidth` with 60 fps. */
            this.comboBoxMenuWidth = this.$refs.comboBoxWrapper.clientWidth + 2;
        }, 1 / 60);
        const observer = new ResizeObserver(cb);
        observer.observe(this.$refs.comboBoxWrapper);
    }
    test() {
        return (<div>Test {this.comboBoxMenuWidth}</div>);
    }
    get hasErrorMessage() {
        const errorMessage = this.errorMessage;
        return !!(errorMessage && errorMessage.length > 0);
    }
    get classNames() {
        const { theme, className, styles: customStyles, disabled, required, allowFreeform, hasErrorMessage } = this;
        const { isOpen, focused, suggestedDisplayValue } = this.state;
        return getClassNames(getStyles(theme, customStyles), className, !!isOpen, !!disabled, !!required, !!focused, !!allowFreeform, !!hasErrorMessage);
    }
    /**
     * Gets the current comboBoxWrapper width, including its border offset. Has to be recalculated on each render cycle of
     * the Callout, in case the window size changed.
     */
    getComboBoxMenuWidth() {
        if (!this.$refs.comboBoxWrapper)
            return 0;
        return this.$refs.comboBoxWrapper.clientWidth + 2;
    }
    onFocus(e) {
    }
    onBlur(e) {
        console.log(e);
    }
    render() {
        const { classNames, onFocus, onBlur, calloutProps, persistMenu, state, multiSelect } = this;
        return (<div class={classNames.container}>
        <Label for={`ComboBox${this.uid}`} class={classNames.label}>Label</Label>
        <div ref="comboBoxWrapper" class={classNames.root}>
          <Autofill id={`ComboBox${this.uid}`} ref="autofill" type="text" role="combobox" class={classNames.input}/>
          <IconButton class="ms-ComboBox-CaretDown-button" icon-props={{ iconName: 'ChevronDown' }} nativeOnFocus={onFocus} nativeOnBlur={onBlur}/>
        </div>

        {this.test()}

        {(persistMenu || state.isOpen) && (<div>
            <Callout class={css(classNames.callout, calloutProps ? calloutProps.className : undefined)} target={this.$refs.comboBoxWrapper} is-beak-visible={false} gap-space={0} do-not-layer={false} callout-width={this.getComboBoxMenuWidth()} callout-max-width={this.getComboBoxMenuWidth()} hidden={persistMenu ? !state.isOpen : undefined}>
              <div ref="comboBoxMenu" class={classNames.optionsContainerWrapper}>
                <div class={classNames.optionsContainer} role="listbox">
                  {multiSelect && (<Checkbox class="ms-ComboBox-option"/>)}
                  <ActionButton class="ms-ComboBox-option">
                  </ActionButton>
                </div>
              </div>
            </Callout>
          </div>)}
      </div>);
    }
};
__decorate([
    Prop(),
    __metadata("design:type", Boolean)
], ComboBoxBase.prototype, "allowFreeform", void 0);
__decorate([
    Prop(),
    __metadata("design:type", String)
], ComboBoxBase.prototype, "autoComplete", void 0);
__decorate([
    Prop(),
    __metadata("design:type", String)
], ComboBoxBase.prototype, "errorMessage", void 0);
__decorate([
    Prop(),
    __metadata("design:type", Object)
], ComboBoxBase.prototype, "text", void 0);
__decorate([
    Prop(),
    __metadata("design:type", Object)
], ComboBoxBase.prototype, "calloutProps", void 0);
__decorate([
    Prop(),
    __metadata("design:type", Object)
], ComboBoxBase.prototype, "buttonIconProps", void 0);
__decorate([
    Prop(),
    __metadata("design:type", Object)
], ComboBoxBase.prototype, "comboBoxOptionStyles", void 0);
__decorate([
    Prop(),
    __metadata("design:type", Boolean)
], ComboBoxBase.prototype, "autofill", void 0);
__decorate([
    Prop(),
    __metadata("design:type", Boolean)
], ComboBoxBase.prototype, "disabled", void 0);
__decorate([
    Prop(),
    __metadata("design:type", Boolean)
], ComboBoxBase.prototype, "required", void 0);
__decorate([
    Prop(),
    __metadata("design:type", Boolean)
], ComboBoxBase.prototype, "persistMenu", void 0);
__decorate([
    Prop({ type: Boolean, default: false }),
    __metadata("design:type", Boolean)
], ComboBoxBase.prototype, "multiSelect", void 0);
ComboBoxBase = __decorate([
    Component({
        components: { Autofill, Label, IconButton, Callout, ActionButton, Checkbox, VNodes },
    })
], ComboBoxBase);
export { ComboBoxBase };
//# sourceMappingURL=ComboBox.base.jsx.map