import { __decorate, __metadata } from "tslib";
import { Component, Prop } from 'vue-property-decorator';
import { Callout } from '../Callout';
import { DirectionalHint } from '../../common/DirectionalHint';
import { css, classNamesFunction } from '@uifabric-vue/utilities';
import BaseComponent from '../BaseComponent';
import { ContextualMenuItem } from './ContextualMenuItem';
const getClassNames = classNamesFunction({
    disableCaching: true,
});
let ContextualMenuBase = class ContextualMenuBase extends BaseComponent {
    created() {
        console.log(this.target);
    }
    get classNames() {
        const { styles, theme, className } = this;
        return getClassNames(styles, {
            theme,
            className,
        });
    }
    get contextMenuStyle() {
        const targetBoundingRect = this.target.getBoundingClientRect();
        const targetWidth = targetBoundingRect.width - 2; /* Accounts for 1px border */
        return {
            width: `${targetWidth}px`,
        };
    }
    render() {
        const { target, directionalHint, calloutProps, onDismiss, contextMenuStyle, classNames, items } = this;
        return (<Callout target={target} directional-hint={directionalHint} class={css('ms-ContextualMenu-Callout', calloutProps && calloutProps.className)} is-beak-visible={false} onDismiss={onDismiss}>
        <div style={contextMenuStyle} class={classNames.container}>
          <div class={classNames.root}>
            <ul class={classNames.list} role="menu">
              {items.map((item, index) => (<li key={item.key || index} class={classNames.item}>
                  <ContextualMenuItem item={item} prop-class-names={classNames}/>
                </li>))}
            </ul>
          </div>
        </div>
      </Callout>);
    }
};
__decorate([
    Prop(),
    __metadata("design:type", HTMLElement)
], ContextualMenuBase.prototype, "target", void 0);
__decorate([
    Prop({ type: Object, default: () => { } }),
    __metadata("design:type", Object)
], ContextualMenuBase.prototype, "calloutProps", void 0);
__decorate([
    Prop({ type: Number, default: DirectionalHint.bottomAutoEdge }),
    __metadata("design:type", Boolean)
], ContextualMenuBase.prototype, "directionalHint", void 0);
__decorate([
    Prop({ type: Function, default: () => null }),
    __metadata("design:type", Function)
], ContextualMenuBase.prototype, "onDismiss", void 0);
__decorate([
    Prop({ type: Array, default: () => [] }),
    __metadata("design:type", Array)
], ContextualMenuBase.prototype, "items", void 0);
ContextualMenuBase = __decorate([
    Component({
        components: { Callout, ContextualMenuItem },
    })
], ContextualMenuBase);
export { ContextualMenuBase };
//# sourceMappingURL=ContextualMenu.base.jsx.map