import { __decorate, __metadata } from "tslib";
import { Component, Prop } from 'vue-property-decorator';
import BaseComponent from '../BaseComponent';
import { Layer } from '../Layer';
import { Modal } from '../Modal';
import { DialogContent } from './DialogContent';
import { classNamesFunction } from '@uifabric-vue/utilities';
import { DialogType } from './DialogContent.types';
import { ResponsiveMode } from '../../utilities';
const getClassNames = classNamesFunction();
const DefaultModalProps = {
    isDarkOverlay: false,
    isBlocking: false,
    className: '',
    containerClassName: '',
    topOffsetFixed: false,
};
const DefaultDialogContentProps = {
    type: DialogType.normal,
    className: '',
    topButtonsProps: [],
};
let DialogBase = class DialogBase extends BaseComponent {
    get mergedLayerProps() {
        const { modalProps, onLayerDidMount } = this;
        const mergedLayerProps = {
            ...(modalProps ? modalProps.layerProps : { onLayerDidMount }),
        };
        if (onLayerDidMount && !mergedLayerProps.onLayerDidMount) {
            mergedLayerProps.onLayerDidMount = onLayerDidMount;
        }
        return mergedLayerProps;
    }
    get dragOptions() {
        const { modalProps } = this;
        let dialogDraggableClassName;
        let dragOptions;
        // if we are draggable, make sure we are using the correct
        // draggable classname and selectors
        if (modalProps && modalProps.dragOptions && !modalProps.dragOptions.dragHandleSelector) {
            dialogDraggableClassName = 'ms-Dialog-draggable-header';
            dragOptions = {
                ...modalProps.dragOptions,
                dragHandleSelector: `.${dialogDraggableClassName}`,
            };
        }
        else {
            dragOptions = modalProps && modalProps.dragOptions;
        }
        return dragOptions;
    }
    get mergedModalProps() {
        const { className, modalProps, dragOptions } = this;
        return {
            className,
            ...DefaultModalProps,
            ...modalProps,
            layerProps: this.mergedLayerProps,
            dragOptions,
        };
    }
    get classNames() {
        const { styles, theme, mergedModalProps, hidden, minWidth, maxWidth } = this;
        return getClassNames(styles, {
            theme: theme,
            className: mergedModalProps.className,
            hidden,
            dialogDefaultMinWidth: minWidth,
            dialogDefaultMaxWidth: maxWidth,
        });
    }
    render() {
        const { classNames, mergedModalProps, hidden, responsiveMode } = this;
        const onDismiss = ev => this.$emit('dismiss', ev);
        const dialogContentProps = {
            ...DefaultDialogContentProps,
            ...this.dialogContentProps,
            // draggableHeaderClassName: dialogDraggableClassName,
            titleProps: {
                // tslint:disable-next-line:deprecation
                id: this._getTitleTextId(),
                ...this.dialogContentProps?.titleProps,
            },
        };
        return (<Modal 
        // elementToFocusOnDismiss={elementToFocusOnDismiss}
        // firstFocusableSelector={firstFocusableSelector}
        // forceFocusInsideTrap={forceFocusInsideTrap}
        // ignoreExternalFocusing={ignoreExternalFocusing}
        // isClickableOutsideFocusTrap={isClickableOutsideFocusTrap}
        responsiveMode={responsiveMode} {...mergedModalProps} isDarkOverlay={mergedModalProps.isDarkOverlay} isBlocking={mergedModalProps.isBlocking} isOpen={!hidden} class={classNames.root} containerClassName={classNames.main} onDismiss={onDismiss || mergedModalProps.onDismiss} subtitleAriaId={this._getSubTextId()} titleAriaId={this._getTitleTextId()}>
        <DialogContent subTextId={this._getSubTextId()} title={dialogContentProps.title} subText={dialogContentProps.subText} showCloseButton={mergedModalProps.isBlocking} topButtonsProps={dialogContentProps.topButtonsProps} type={dialogContentProps.type} onDismiss={onDismiss || dialogContentProps.onDismiss} class={dialogContentProps.className} {...dialogContentProps}>
          {this.$slots.default}
        </DialogContent>
      </Modal>);
    }
    _getSubTextId() {
        return `${this.uid}-subText`;
        // // tslint:disable-next-line:deprecation
        // const { ariaDescribedById, modalProps, dialogContentProps, subText } = this.props
        // let id = (modalProps && modalProps.subtitleAriaId) || ariaDescribedById
        // if (!id) {
        //   id = ((dialogContentProps && dialogContentProps.subText) || subText) && this._defaultSubTextId
        // }
        // return id
    }
    ;
    _getTitleTextId() {
        return `${this.uid}-title`;
        // // tslint:disable-next-line:deprecation
        // const { ariaLabelledById, modalProps, dialogContentProps, title } = this.props
        // let id = (modalProps && modalProps.titleAriaId) || ariaLabelledById
        // if (!id) {
        //   id = ((dialogContentProps && dialogContentProps.title) || title) && this._defaultTitleTextId
        // }
        // return id
    }
    ;
};
__decorate([
    Prop({ type: Object, default: () => { } }),
    __metadata("design:type", Object)
], DialogBase.prototype, "dialogContentProps", void 0);
__decorate([
    Prop({ type: Boolean, default: true }),
    __metadata("design:type", Boolean)
], DialogBase.prototype, "hidden", void 0);
__decorate([
    Prop({ type: Object, default: null }),
    __metadata("design:type", Object)
], DialogBase.prototype, "modalProps", void 0);
__decorate([
    Prop({ type: String, default: null }),
    __metadata("design:type", Object)
], DialogBase.prototype, "minWidth", void 0);
__decorate([
    Prop({ type: String, default: null }),
    __metadata("design:type", Object)
], DialogBase.prototype, "maxWidth", void 0);
__decorate([
    Prop({ type: Function, default: null }),
    __metadata("design:type", Object)
], DialogBase.prototype, "onLayerDidMount", void 0);
__decorate([
    Prop({ type: Number, default: null }),
    __metadata("design:type", Number)
], DialogBase.prototype, "responsiveMode", void 0);
DialogBase = __decorate([
    Component({
        components: { Layer },
    })
], DialogBase);
export { DialogBase };
//# sourceMappingURL=Dialog.base.jsx.map