import { __decorate, __metadata } from "tslib";
import { Component, Prop } from 'vue-property-decorator';
import BaseComponent from '../BaseComponent';
import { classNamesFunction } from '@uifabric-vue/utilities';
import { DialogType } from './DialogContent.types';
import { IconButton } from '../Button';
const getClassNames = classNamesFunction();
let DialogContentBase = class DialogContentBase extends BaseComponent {
    get classNames() {
        const { styles, theme, className, type, draggableHeaderClassName } = this;
        return getClassNames(styles, {
            theme: theme,
            className,
            isLargeHeader: type === DialogType.largeHeader,
            isClose: type === DialogType.close,
            draggableHeaderClassName,
        });
    }
    render() {
        const { classNames, css, title, type, showCloseButton, closeButtonAriaLabel, subText, subTextId } = this;
        const titleProps = this.titleProps || {};
        let subTextContent;
        if (subText) {
            subTextContent = (<p class={classNames.subText} id={subTextId}>
          {subText}
        </p>);
        }
        return (<div class={classNames.content}>
        <div class={classNames.header}>
          <div id={titleProps.id} role="heading" aria-level={1} {...titleProps} class={css(classNames.title, titleProps.className)}>
            {title}
          </div>
          <div class={classNames.topButton}>
            
            {(type === DialogType.close || (showCloseButton && type !== DialogType.largeHeader)) && (<IconButton class={classNames.button} iconProps={{ iconName: 'Cancel' }} ariaLabel={closeButtonAriaLabel} onClick={ev => this.$emit('dismiss', ev)} title={closeButtonAriaLabel}/>)}
          </div>
        </div>
        <div class={classNames.inner}>
          <div class={classNames.innerContent}>
            {subTextContent}
            {this.$slots.default}
          </div>
          {this.$slots.footer}
        </div>
      </div>);
    }
};
__decorate([
    Prop({ type: Number, default: DialogType.normal }),
    __metadata("design:type", Number)
], DialogContentBase.prototype, "type", void 0);
__decorate([
    Prop({ type: String, default: null }),
    __metadata("design:type", String)
], DialogContentBase.prototype, "draggableHeaderClassName", void 0);
__decorate([
    Prop({ type: Object, default: () => { } }),
    __metadata("design:type", Object)
], DialogContentBase.prototype, "titleProps", void 0);
__decorate([
    Prop({ type: [String, Object], default: null }),
    __metadata("design:type", Object)
], DialogContentBase.prototype, "title", void 0);
__decorate([
    Prop({ type: Boolean, default: false }),
    __metadata("design:type", Boolean)
], DialogContentBase.prototype, "showCloseButton", void 0);
__decorate([
    Prop({ type: String, default: 'Close' }),
    __metadata("design:type", String)
], DialogContentBase.prototype, "closeButtonAriaLabel", void 0);
__decorate([
    Prop({ type: String, default: null }),
    __metadata("design:type", String)
], DialogContentBase.prototype, "subText", void 0);
__decorate([
    Prop({ type: String, default: null }),
    __metadata("design:type", String)
], DialogContentBase.prototype, "subTextId", void 0);
DialogContentBase = __decorate([
    Component
], DialogContentBase);
export { DialogContentBase };
//# sourceMappingURL=DialogContent.base.jsx.map