import { __decorate, __metadata } from "tslib";
import { Component, Prop } from 'vue-property-decorator';
import { classNamesFunction } from '@uifabric-vue/utilities';
import StatelessComponent from '../StatelessComponent';
import { getIconContent } from './FontIcon';
import { ImageLoadState } from '../Image';
const getClassNames = classNamesFunction({
    // Icon is used a lot by other components.
    // It's likely to see expected cases which pass different className to the Icon.
    // Therefore setting a larger cache size.
    cacheSize: 100,
});
let Icon = class Icon extends StatelessComponent {
    render(h, ctx) {
        const { className, iconName, theme, styles, imageErrorAs } = ctx.props;
        const isPlaceholder = typeof iconName === 'string' && iconName.length === 0;
        const isImage = !!ctx.props.imageProps;
        const iconContent = getIconContent(iconName) || {};
        const { iconClassName } = iconContent;
        const iconContentChildren = iconContent.children;
        const classNames = getClassNames(styles, {
            theme,
            className,
            iconClassName,
            isImage,
            isPlaceholder,
        });
        const RootType = isImage ? 'span' : 'i';
        let imageLoadError = false;
        const imageProps = {
            ...ctx.props.imageProps,
            onLoadingStateChange: (state) => {
                if (ctx.props.imageProps && ctx.props.imageProps.onLoadingStateChange) {
                    ctx.props.imageProps.onLoadingStateChange(state);
                }
                if (state === ImageLoadState.error) {
                    imageLoadError = true;
                }
            },
        };
        const ImageType = (imageLoadError && imageErrorAs) || Image;
        const ariaLabel = ctx.data.attrs && (ctx.data.attrs['aria-label'] || ctx.data.attrs.ariaLabel);
        const containerProps = ariaLabel
            ? {
                'aria-label': ariaLabel,
            }
            : {
                'aria-hidden': !(ctx.props['aria-labelledby'] || imageProps['aria-labelledby']),
            };
        return (<RootType data-icon-name={iconName} {...{ ...ctx.data, props: containerProps }} class={classNames.root}>
        {isImage
            // @ts-ignore
            ? (<ImageType {...{ props: imageProps }}/>)
            : ((ctx.scopedSlots.default && ctx.scopedSlots.default({})) || (typeof iconContentChildren === 'function'
                ? iconContentChildren(h)
                : iconContentChildren))}
      </RootType>);
    }
};
__decorate([
    Prop({ type: String, default: '' }),
    __metadata("design:type", String)
], Icon.prototype, "iconName", void 0);
__decorate([
    Prop({ type: Object, default: null }),
    __metadata("design:type", Object)
], Icon.prototype, "imageProps", void 0);
__decorate([
    Prop({ type: [String, Object], default: null }),
    __metadata("design:type", Object)
], Icon.prototype, "imageErrorAs", void 0);
Icon = __decorate([
    Component
], Icon);
export default Icon;
//# sourceMappingURL=Icon.jsx.map