import { __decorate, __metadata } from "tslib";
import { Component, Prop, Watch } from 'vue-property-decorator';
import BaseComponent from '../BaseComponent';
import { MessageBarType } from './MessageBar.types';
import { classNamesFunction } from '@uifabric-vue/utilities';
import { Icon } from '../Icon';
import { IconButton } from '../Button';
const getClassNames = classNamesFunction();
const ICON_MAP = {
    [MessageBarType.info]: 'Info',
    [MessageBarType.warning]: 'Info',
    [MessageBarType.error]: 'ErrorBadge',
    [MessageBarType.blocked]: 'Blocked2',
    [MessageBarType.severeWarning]: 'Warning',
    [MessageBarType.success]: 'Completed',
};
let MessageBarBase = class MessageBarBase extends BaseComponent {
    constructor() {
        super(...arguments);
        this.state = {
            expandSingleLine: this.expandSingleLine,
        };
    }
    get classNames() {
        const { theme, className, messageBarType, actions, truncated, isMultiline } = this;
        const { expandSingleLine } = this.state;
        return getClassNames(this.styles, {
            theme,
            messageBarType: messageBarType || MessageBarType.info,
            onDismiss: this.$listeners.dismiss !== undefined,
            actions: actions !== undefined,
            truncated: truncated,
            isMultiline: isMultiline,
            expandSingleLine: expandSingleLine,
            className,
        });
    }
    onExpandSingleLine(value) {
        this.state.expandSingleLine = value;
    }
    onClick() {
        this.state.expandSingleLine = !this.state.expandSingleLine;
    }
    render() {
        const { theme, classNames, messageBarType, actions, truncated, isMultiline } = this;
        return (<div style={{ background: theme.semanticColors.bodyBackground }}>
        <div class={classNames.root}>
          <div class={classNames.content}>
            
            <div class={classNames.iconContainer}>
              <Icon class={classNames.icon} icon-name={ICON_MAP[messageBarType]}/>
            </div>

            
            <div class={classNames.text} role="status">
              <span class={classNames.innerText}>
                <span>{this.$slots.default}</span>
              </span>
            </div>

            
            {(!actions && truncated) && (<div class={classNames.expandSingleLine}>
                <IconButton class={classNames.expand} icon-props={{ iconName: this.state.expandSingleLine ? 'DoubleChevronUp' : 'DoubleChevronDown' }} nativeOnClick={this.onClick}/>
              </div>)}

            
            {(!isMultiline && this.$slots.actions) && (<div class={classNames.actions}>
                {this.$slots.actions}
              </div>)}

            
            {(this.$listeners.dismiss && isMultiline) && (<IconButton class={classNames.dismissal} icon-props={{ iconName: 'Clear' }}/>)}

            
            {(this.$listeners.dismiss && !isMultiline) && (<div class={classNames.dismissSingleLine}>
                <IconButton class={classNames.dismissal} icon-props={{ iconName: 'Clear' }}/>
              </div>)}

          </div>

          
          {(isMultiline && this.$slots.actions) && (<div class={classNames.actions}>
              {this.$slots.actions}
            </div>)}
        </div>
      </div>);
    }
};
__decorate([
    Prop({ type: Number, default: MessageBarType.info }),
    __metadata("design:type", Number)
], MessageBarBase.prototype, "messageBarType", void 0);
__decorate([
    Prop({ type: Boolean, default: true }),
    __metadata("design:type", Boolean)
], MessageBarBase.prototype, "isMultiline", void 0);
__decorate([
    Prop({ type: Boolean, default: false }),
    __metadata("design:type", Boolean)
], MessageBarBase.prototype, "actions", void 0);
__decorate([
    Prop({ type: Boolean, default: false }),
    __metadata("design:type", Boolean)
], MessageBarBase.prototype, "truncated", void 0);
__decorate([
    Prop({ type: Boolean, default: true }),
    __metadata("design:type", Boolean)
], MessageBarBase.prototype, "expandSingleLine", void 0);
__decorate([
    Watch('expandSingleLine'),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Boolean]),
    __metadata("design:returntype", void 0)
], MessageBarBase.prototype, "onExpandSingleLine", null);
MessageBarBase = __decorate([
    Component({
        components: { Icon, IconButton },
    })
], MessageBarBase);
export { MessageBarBase };
//# sourceMappingURL=MessageBar.base.jsx.map