import { __decorate, __metadata } from "tslib";
import { Component, Prop, Watch } from 'vue-property-decorator';
import BaseComponent from '../BaseComponent';
import { Layer } from '../Layer';
import { classNamesFunction } from '@uifabric-vue/utilities';
import { Popup } from '../Popup';
import { Overlay } from '../Overlay';
import { Icon } from '../Icon';
import { DirectionalHint } from '../Callout';
import { ResponsiveMode } from '../../utilities';
const getClassNames = classNamesFunction();
const DefaultLayerProps = {
    eventBubblingEnabled: false,
};
let ModalBase = class ModalBase extends BaseComponent {
    constructor() {
        super(...arguments);
        this.internalIsOpen = false;
        this.isVisible = false;
        this.isVisibleClose = false;
        this.hasBeenOpened = false;
        this.modalRectangleTop = 0;
        this.isModalMenuOpen = false;
        this.isInKeyboardMoveMode = false;
        this.x = 0;
        this.y = 0;
        this.lastSetX = 0;
        this.lastSetY = 0;
        this.responsiveMode = ResponsiveMode.large;
    }
    onIsOpenChanged(newVal) {
        if (newVal)
            this.isVisible = true;
    }
    get classNames() {
        const { theme, styles, className, layerProps, containerClassName, scrollableContentClassName, isVisible, hasBeenOpened, modalRectangleTop, topOffsetFixed, isModeless, dragOptions, isOpen, } = this;
        const layerClassName = layerProps == null ? '' : layerProps.className;
        return getClassNames(styles, {
            theme: theme,
            className,
            containerClassName,
            scrollableContentClassName,
            isOpen,
            isVisible,
            hasBeenOpened,
            modalRectangleTop,
            topOffsetFixed,
            isModeless,
            layerClassName,
            isDefaultDragHandle: dragOptions && !dragOptions.dragHandleSelector,
        });
    }
    onModalContextMenuClose() {
        this.isModalMenuOpen = false;
    }
    onModalClose() {
        this.isModalMenuOpen = false;
        this.isInKeyboardMoveMode = false;
        this.isOpen = false;
        // TODO
    }
    onEnterKeyboardMoveMode() {
        this.lastSetX = this.x;
        this.lastSetY = this.y;
        this.isInKeyboardMoveMode = true;
        this.isModalMenuOpen = true;
        // TODO
        // this._events.on(window, 'keydown', this._onKeyDown, true /* useCapture */);
    }
    ;
    _onDragStart() {
        this.isModalMenuOpen = false;
        this.isInKeyboardMoveMode = false;
    }
    ;
    _onDrag(_, ui) {
        this.x += ui.delta.x;
        this.y += ui.delta.y;
    }
    ;
    _onDragStop() {
        // this.focus()
    }
    ;
    onDismiss(ev) {
        this.$emit('dismiss', ev);
    }
    render() {
        const { dragOptions, isInKeyboardMoveMode, classNames, isOpen, responsiveMode, isModeless, layerProps, isBlocking, titleAriaId, subtitleAriaId, isDarkOverlay, onDismiss, overlay, ignoreExternalFocusing, x, y, } = this;
        if (!isOpen)
            return null;
        const mergedLayerProps = {
            ...DefaultLayerProps,
            ...this.layerProps,
            onLayerDidMount: layerProps && layerProps.onLayerDidMount,
            insertFirst: isModeless,
            className: classNames.layer,
        };
        const modalContent = (<div class={classNames.main}>
        {dragOptions && isInKeyboardMoveMode && (<div class={classNames.keyboardMoveIconContainer}>
            {dragOptions.keyboardMoveIconProps ? (<Icon {...dragOptions.keyboardMoveIconProps}/>) : (<Icon iconName="move" class={classNames.keyboardMoveIcon}/>)}
          </div>)}
        <div ref="scrollableContent" class={classNames.scrollableContent} data-is-scrollable={true}>
          {dragOptions && this.isModalMenuOpen && (<dragOptions.menu items={[
            { key: 'move', text: dragOptions.moveMenuItemText, onClick: this.onEnterKeyboardMoveMode },
            { key: 'close', text: dragOptions.closeMenuItemText, onClick: this.onModalClose },
        ]} onDismiss={this.onModalContextMenuClose} alignTargetEdge={true} coverTarget={true} directionalHint={DirectionalHint.topLeftEdge} directionalHintFixed={true} shouldFocusOnMount={true} target={this.$refs.scrollableContent}/>)}
          {this.$slots.default}
        </div>
      </div>);
        if (responsiveMode >= ResponsiveMode.small) {
            return (<Layer {...mergedLayerProps}>
          <Popup role={isModeless || !isBlocking ? 'dialog' : 'alertdialog'} aria-modal={!isModeless} ariaLabelledBy={titleAriaId} ariaDescribedBy={subtitleAriaId} onDismiss={onDismiss} shouldRestoreFocus={!ignoreExternalFocusing}>
            <div class={classNames.root}>
              {!isModeless && (<Overlay dark={isDarkOverlay} onClick={isBlocking ? undefined : onDismiss} allowTouchBodyScroll={this.allowTouchBodyScroll} {...{ props: overlay }}/>)}
              {dragOptions ? (
            // <DraggableZone
            //   handleSelector={dragOptions.dragHandleSelector || `.${classNames.main.split(' ')[0]}`}
            //   preventDragSelector="button"
            //   onStart={this._onDragStart}
            //   onDragChange={this._onDrag}
            //   onStop={this._onDragStop}
            //   position={{ x: x, y: y }}
            // >
            modalContent
            // </DraggableZone>
            ) : (modalContent)}
            </div>
          </Popup>
        </Layer>);
        }
    }
};
__decorate([
    Prop({ type: Boolean, default: false }),
    __metadata("design:type", Boolean)
], ModalBase.prototype, "isOpen", void 0);
__decorate([
    Prop({ type: Boolean, default: true }),
    __metadata("design:type", Boolean)
], ModalBase.prototype, "isDarkOverlay", void 0);
__decorate([
    Prop({ type: Function, default: null }),
    __metadata("design:type", Function)
], ModalBase.prototype, "onDismissed", void 0);
__decorate([
    Prop({ type: Object, default: null }),
    __metadata("design:type", Object)
], ModalBase.prototype, "layerProps", void 0);
__decorate([
    Prop({ type: Object, default: null }),
    __metadata("design:type", Object)
], ModalBase.prototype, "overlay", void 0);
__decorate([
    Prop({ type: Boolean, default: false }),
    __metadata("design:type", Boolean)
], ModalBase.prototype, "isBlocking", void 0);
__decorate([
    Prop({ type: Boolean, default: false }),
    __metadata("design:type", Boolean)
], ModalBase.prototype, "isModeless", void 0);
__decorate([
    Prop({ type: String, default: '' }),
    __metadata("design:type", String)
], ModalBase.prototype, "className", void 0);
__decorate([
    Prop({ type: String, default: '' }),
    __metadata("design:type", String)
], ModalBase.prototype, "containerClassName", void 0);
__decorate([
    Prop({ type: String, default: '' }),
    __metadata("design:type", String)
], ModalBase.prototype, "scrollableContentClassName", void 0);
__decorate([
    Prop({ type: String, default: '' }),
    __metadata("design:type", String)
], ModalBase.prototype, "titleAriaId", void 0);
__decorate([
    Prop({ type: String, default: '' }),
    __metadata("design:type", String)
], ModalBase.prototype, "subtitleAriaId", void 0);
__decorate([
    Prop({ type: Boolean, default: false }),
    __metadata("design:type", Boolean)
], ModalBase.prototype, "topOffsetFixed", void 0);
__decorate([
    Prop({ type: Object, default: null }),
    __metadata("design:type", Object)
], ModalBase.prototype, "dragOptions", void 0);
__decorate([
    Prop({ type: Boolean, default: false }),
    __metadata("design:type", Boolean)
], ModalBase.prototype, "allowTouchBodyScroll", void 0);
__decorate([
    Prop({ type: Boolean, default: false }),
    __metadata("design:type", Boolean)
], ModalBase.prototype, "ignoreExternalFocusing", void 0);
__decorate([
    Watch('isOpen'),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object]),
    __metadata("design:returntype", void 0)
], ModalBase.prototype, "onIsOpenChanged", null);
ModalBase = __decorate([
    Component
], ModalBase);
export { ModalBase };
//# sourceMappingURL=Modal.base.jsx.map