import { __decorate, __metadata } from "tslib";
import { Component, Prop } from 'vue-property-decorator';
import BaseComponent from '../../BaseComponent';
import { classNamesFunction, getInitials, getRTL } from '@uifabric-vue/utilities';
import { mergeStyles } from '@uifabric/merge-styles';
import { getPersonaInitialsColor } from '../PersonaInitialsColor';
import { PersonaSize, PersonaPresence as PersonaPresenceEnum, } from '../Persona.types';
import { PersonaPresence } from '../PersonaPresence/';
import { sizeToPixels } from '../PersonaConsts';
import { ImageFit, Image } from '../../Image';
import { Icon } from '../../Icon';
const getClassNames = classNamesFunction({
    // There can be many PersonaCoin rendered with different sizes.
    // Therefore setting a larger cache size.
    cacheSize: 100,
});
let PersonaCoinBase = class PersonaCoinBase extends BaseComponent {
    constructor() {
        super(...arguments);
        this.mergeStyles = mergeStyles;
        this.getPersonaInitialsColor = getPersonaInitialsColor;
        this.PersonaSize = PersonaSize;
        this.ImageFit = ImageFit;
    }
    get initials() {
        const { imageInitials, allowPhoneInitials, showUnknownPersonaCoin } = this;
        const isRTL = getRTL(this.theme);
        return imageInitials || getInitials(this.text, isRTL, allowPhoneInitials);
    }
    get dimension() {
        const { coinSize, size } = this;
        return coinSize || sizeToPixels[size];
    }
    get personaPresenceProps() {
        const { coinSize, theme, isOutOfOffice, presence, presenceTitle, size } = this;
        return {
            coinSize,
            isOutOfOffice,
            presence,
            presenceTitle,
            size,
            theme,
        };
    }
    get shouldRenderInitials() {
        return !this.imageUrl;
    }
    get coinSizeStyle() {
        const { coinSize } = this;
        return coinSize ? { width: coinSize, height: coinSize } : undefined;
    }
    get classNames() {
        const { styles, theme, className, coinProps, size, coinSize, showUnknownPersonaCoin } = this;
        return getClassNames(styles, {
            theme: theme,
            className: coinProps && coinProps.className ? coinProps.className : className,
            size,
            coinSize,
            showUnknownPersonaCoin,
        });
    }
    render() {
        const { classNames, size, initials, presence, personaPresenceProps, coinSizeStyle, shouldRenderInitials, showUnknownPersonaCoin, imageUrl, dimension } = this;
        return (<div role="presentation" class={classNames.coin}>
        {(size !== PersonaSize.size8) ? (<div role="presentation" class={classNames.imageArea} style={coinSizeStyle}>
            {shouldRenderInitials && (<div class={mergeStyles(classNames.initials, !showUnknownPersonaCoin && { backgroundColor: getPersonaInitialsColor(this.$props) })} style={coinSizeStyle} aria-hidden="true">
                {initials
            ? (<span>{initials}</span>)
            : (<Icon icon-name="Contact"/>)}
              </div>)}

            {imageUrl && (<Image class={classNames.image} image-fit={ImageFit.cover} src={imageUrl} width={dimension} height={dimension}/>)}
            <PersonaPresence {...{ props: personaPresenceProps }}/>
          </div>) : presence
            ? (<PersonaPresence {...{ props: personaPresenceProps }}/>)
            : (<Icon icon-name="Contact" class={classNames.size10WithoutPresenceIcon}/>)}

        {this.$slots.default}
      </div>);
    }
};
__decorate([
    Prop({ type: Boolean, default: false }),
    __metadata("design:type", Boolean)
], PersonaCoinBase.prototype, "allowPhoneInitials", void 0);
__decorate([
    Prop({ type: Number, default: PersonaPresenceEnum.none }),
    __metadata("design:type", Number)
], PersonaCoinBase.prototype, "presence", void 0);
__decorate([
    Prop({ type: Number, default: null }),
    __metadata("design:type", Number)
], PersonaCoinBase.prototype, "size", void 0);
__decorate([
    Prop({ type: Number, default: null }),
    __metadata("design:type", Number)
], PersonaCoinBase.prototype, "coinSize", void 0);
__decorate([
    Prop(),
    __metadata("design:type", Object)
], PersonaCoinBase.prototype, "coinProps", void 0);
__decorate([
    Prop(),
    __metadata("design:type", Object)
], PersonaCoinBase.prototype, "showUnknownPersonaCoin", void 0);
__decorate([
    Prop(),
    __metadata("design:type", Object)
], PersonaCoinBase.prototype, "isOutOfOffice", void 0);
__decorate([
    Prop(),
    __metadata("design:type", Object)
], PersonaCoinBase.prototype, "presenceTitle", void 0);
__decorate([
    Prop(),
    __metadata("design:type", Object)
], PersonaCoinBase.prototype, "imageUrl", void 0);
__decorate([
    Prop(),
    __metadata("design:type", Object)
], PersonaCoinBase.prototype, "imageInitials", void 0);
__decorate([
    Prop(),
    __metadata("design:type", Object)
], PersonaCoinBase.prototype, "text", void 0);
__decorate([
    Prop(),
    __metadata("design:type", Object)
], PersonaCoinBase.prototype, "initialsColor", void 0);
PersonaCoinBase = __decorate([
    Component({
        inheritAttrs: false,
        components: { Icon, OImage: Image, PersonaPresence },
    })
], PersonaCoinBase);
export { PersonaCoinBase };
//# sourceMappingURL=PersonaCoin.base.jsx.map