import { __decorate, __metadata } from "tslib";
import { Component, Prop } from 'vue-property-decorator';
import BaseComponent from '../../BaseComponent';
import { classNamesFunction } from '@uifabric-vue/utilities';
import { PersonaPresence as PersonaPresenceEnum, } from '../Persona.types';
import { sizeBoolean } from '../PersonaConsts';
import { Icon } from '../../Icon';
const coinSizeFontScaleFactor = 6;
const coinSizePresenceScaleFactor = 3;
const presenceMaxSize = 40;
const presenceFontMaxSize = 20;
const getClassNames = classNamesFunction({
    // There can be many PersonaPresence rendered with different sizes.
    // Therefore setting a larger cache size.
    cacheSize: 100,
});
let PersonaPresenceBase = class PersonaPresenceBase extends BaseComponent {
    constructor() {
        super(...arguments);
        this.PersonaPresenceEnum = PersonaPresenceEnum;
    }
    get renderIcon() {
        const { coinSize } = this;
        const size = sizeBoolean(this.size);
        return !(size.isSize8 || size.isSize10 || size.isSize16 || size.isSize24 || size.isSize28 || size.isSize32) &&
            (coinSize ? coinSize > 32 : true);
    }
    get presenceHeightWidth() {
        const { coinSize } = this;
        const presenceHeightWidth = coinSize
            ? coinSize / coinSizePresenceScaleFactor < presenceMaxSize
                ? coinSize / coinSizePresenceScaleFactor + 'px'
                : presenceMaxSize + 'px'
            : '';
        return presenceHeightWidth;
    }
    get coinSizeWithPresenceStyle() {
        const { coinSize, presenceHeightWidth } = this;
        return coinSize ? { width: presenceHeightWidth, height: presenceHeightWidth } : undefined;
    }
    get coinSizeWithPresenceIconStyle() {
        const { coinSize, isOutOfOffice, styles, // Use getStyles from props.
        presence, presenceTitle, presenceHeightWidth, } = this;
        const size = sizeBoolean(this.size);
        const presenceFontSize = coinSize
            ? coinSize / coinSizeFontScaleFactor < presenceFontMaxSize
                ? coinSize / coinSizeFontScaleFactor + 'px'
                : presenceFontMaxSize + 'px'
            : '';
        return coinSize ? { fontSize: presenceFontSize, lineHeight: presenceHeightWidth } : undefined;
    }
    get classNames() {
        const { styles, theme, presence, size, isOutOfOffice } = this;
        return getClassNames(styles, {
            theme,
            presence,
            size,
            isOutOfOffice,
        });
    }
    get icon() {
        const { presence, isOutOfOffice } = this;
        if (!presence) {
            return undefined;
        }
        const oofIcon = 'SkypeArrow';
        switch (PersonaPresenceEnum[presence]) {
            case 'online':
                return 'SkypeCheck';
            case 'away':
                return isOutOfOffice ? oofIcon : 'SkypeClock';
            case 'dnd':
                return 'SkypeMinus';
            case 'offline':
                return isOutOfOffice ? oofIcon : '';
        }
        return '';
    }
    render() {
        const { classNames, presence, presenceTitle, coinSizeWithPresenceStyle, coinSizeWithPresenceIconStyle, icon, renderIcon } = this;
        if (presence === PersonaPresenceEnum.none)
            return;
        return (<div class={classNames.presence} title={presenceTitle} style={coinSizeWithPresenceStyle}>
        {renderIcon && (<Icon class={classNames.presenceIcon} icon-name={icon} style={coinSizeWithPresenceIconStyle}/>)}
      </div>);
    }
};
__decorate([
    Prop({ type: Number, required: true }),
    __metadata("design:type", Number)
], PersonaPresenceBase.prototype, "presence", void 0);
__decorate([
    Prop(),
    __metadata("design:type", Object)
], PersonaPresenceBase.prototype, "size", void 0);
__decorate([
    Prop(),
    __metadata("design:type", Object)
], PersonaPresenceBase.prototype, "isOutOfOffice", void 0);
__decorate([
    Prop(),
    __metadata("design:type", Object)
], PersonaPresenceBase.prototype, "coinSize", void 0);
__decorate([
    Prop(),
    __metadata("design:type", Object)
], PersonaPresenceBase.prototype, "presenceTitle", void 0);
PersonaPresenceBase = __decorate([
    Component({
        components: { Icon },
        name: 'PersonaPresence',
    })
], PersonaPresenceBase);
export { PersonaPresenceBase };
//# sourceMappingURL=PersonaPresence.base.jsx.map