import { __decorate, __metadata } from "tslib";
import { Component, Prop } from 'vue-property-decorator';
import BaseComponent from '../BaseComponent';
import { classNamesFunction } from '@uifabric-vue/utilities';
const getClassNames = classNamesFunction();
// if the percentComplete is near 0, don't animate it.
// This prevents animations on reset to 0 scenarios
const ZERO_THRESHOLD = 0.01;
let ProgressIndicatorBase = class ProgressIndicatorBase extends BaseComponent {
    get classNames() {
        const { className, indeterminate, theme, barHeight } = this;
        return getClassNames(this.styles, {
            className,
            indeterminate,
            theme,
            barHeight,
        });
    }
    get progressBarStyles() {
        const { percentComplete } = this;
        return {
            width: percentComplete !== undefined ? percentComplete + '%' : undefined,
            transition: percentComplete !== undefined && percentComplete < ZERO_THRESHOLD ? 'none' : undefined,
        };
    }
    render() {
        const { classNames, label, progressHidden, progressBarStyles, description } = this;
        return (<div class={classNames.root}>
        {label && (<div class={classNames.itemName}>{label}</div>)}

        {!progressHidden && (<div class={classNames.itemProgress}>
            <div class={classNames.progressTrack}/>
            <div class={classNames.progressBar} style={progressBarStyles}/>
          </div>)}

        {description && (<div class={classNames.itemDescription}>{description}</div>)}
      </div>);
    }
};
__decorate([
    Prop({ type: Boolean, default: false }),
    __metadata("design:type", Boolean)
], ProgressIndicatorBase.prototype, "progressHidden", void 0);
__decorate([
    Prop({ type: Boolean, default: false }),
    __metadata("design:type", Boolean)
], ProgressIndicatorBase.prototype, "indeterminate", void 0);
__decorate([
    Prop({ type: Number, default: 0 }),
    __metadata("design:type", Number)
], ProgressIndicatorBase.prototype, "percentComplete", void 0);
__decorate([
    Prop({ type: String, default: null }),
    __metadata("design:type", String)
], ProgressIndicatorBase.prototype, "label", void 0);
__decorate([
    Prop({ type: String, default: null }),
    __metadata("design:type", String)
], ProgressIndicatorBase.prototype, "description", void 0);
__decorate([
    Prop({ type: Number, default: 2 }),
    __metadata("design:type", Number)
], ProgressIndicatorBase.prototype, "barHeight", void 0);
ProgressIndicatorBase = __decorate([
    Component
], ProgressIndicatorBase);
export { ProgressIndicatorBase };
//# sourceMappingURL=ProgressIndicator.base.jsx.map