import { __decorate, __metadata } from "tslib";
import { Component, Prop, Watch } from 'vue-property-decorator';
import { Icon } from '../Icon';
import { IconButton } from '../Button';
import BaseComponent from '../BaseComponent';
import { classNamesFunction } from '@uifabric-vue/utilities';
const getClassNames = classNamesFunction();
let RatingBase = class RatingBase extends BaseComponent {
    constructor() {
        super(...arguments);
        this.internalValue = this.rating;
    }
    get classNames() {
        const { disabled, readonly, theme } = this;
        return getClassNames(this.styles, {
            disabled,
            readOnly: readonly,
            theme,
        });
    }
    get ratingLevels() {
        const { min, max } = this;
        if (min < 0 || max <= min)
            return [];
        var i = min + 1;
        return Array(max - min).fill(undefined).map(() => i++);
    }
    get areaLabel() {
        if (!this.ariaLabelFormat)
            return '';
        return this.ariaLabelFormat.replace('{0}', `${this.internalValue}`).replace('{1}', `${this.max}`);
    }
    getRatingIconName(ratingLevel) {
        return this.internalValue >= ratingLevel ? this.iconName : this.unselectedIconName;
    }
    getRatingFillPercentage(ratingLevel) {
        if (ratingLevel - this.internalValue <= 0)
            return '100%';
        if (ratingLevel - this.internalValue > 1)
            return '0%';
        if (ratingLevel - this.internalValue > 0)
            return `${(1 - (ratingLevel - this.internalValue)) * 100}%`;
    }
    setRating(rating) {
        this.internalValue = rating;
    }
    onPropValueChanged(newValue) {
        this.internalValue = newValue;
    }
    onValueChanged(value) {
        this.$emit('input', value);
    }
    render() {
        const { classNames, readonly, max, size, disabled, iconName } = this;
        return (<div area-label="areaLabel" class={classNames.root} style={{ '--size': `${size}px` }}>
        <div class={classNames.ratingFocusZone}>
          {this.ratingLevels.map(ratingLevel => (<button key={ratingLevel} {...{ attrs: this.$attrs }} class={classNames.ratingButton} disabled={disabled} onClick={() => { !disabled && !readonly && this.setRating(ratingLevel); }}>
              <span class={classNames.labelText}>{`Select ${ratingLevel} of ${max}`}</span>

              <div class={classNames.ratingStar}>
                <Icon icon-name={this.getRatingIconName(ratingLevel)} class={classNames.ratingStarBack}/>
                <Icon icon-name={iconName} class={classNames.ratingStarFront} style={{ width: this.getRatingFillPercentage(ratingLevel) }}/>
              </div>
            </button>))}
        </div>
      </div>);
    }
};
__decorate([
    Prop({ type: Number, default: 16 }),
    __metadata("design:type", Number)
], RatingBase.prototype, "size", void 0);
__decorate([
    Prop({ type: Number, default: 0 }),
    __metadata("design:type", Number)
], RatingBase.prototype, "min", void 0);
__decorate([
    Prop({ type: Number, default: 10 }),
    __metadata("design:type", Number)
], RatingBase.prototype, "max", void 0);
__decorate([
    Prop({ type: Number, default: 0 }),
    __metadata("design:type", Number)
], RatingBase.prototype, "rating", void 0);
__decorate([
    Prop({ type: String, default: '' }),
    __metadata("design:type", String)
], RatingBase.prototype, "ariaLabelFormat", void 0);
__decorate([
    Prop({ type: String, default: 'FavoriteStarFill' }),
    __metadata("design:type", String)
], RatingBase.prototype, "iconName", void 0);
__decorate([
    Prop({ type: String, default: 'FavoriteStar' }),
    __metadata("design:type", String)
], RatingBase.prototype, "unselectedIconName", void 0);
__decorate([
    Prop({ type: Boolean, default: false }),
    __metadata("design:type", Boolean)
], RatingBase.prototype, "disabled", void 0);
__decorate([
    Prop({ type: Boolean, default: false }),
    __metadata("design:type", Boolean)
], RatingBase.prototype, "readonly", void 0);
__decorate([
    Watch('rating'),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Number]),
    __metadata("design:returntype", void 0)
], RatingBase.prototype, "onPropValueChanged", null);
__decorate([
    Watch('internalValue'),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String]),
    __metadata("design:returntype", void 0)
], RatingBase.prototype, "onValueChanged", null);
RatingBase = __decorate([
    Component({
        components: { Icon, IconButton },
        inheritAttrs: false,
    })
], RatingBase);
export { RatingBase };
//# sourceMappingURL=Rating.base.jsx.map