import { __decorate, __metadata } from "tslib";
import { Component, Prop, Watch } from 'vue-property-decorator';
import { Icon } from '../Icon';
import { IconButton } from '../Button';
import BaseComponent from '../BaseComponent';
import { classNamesFunction, KeyCodes } from '@uifabric-vue/utilities';
const getClassNames = classNamesFunction();
let SearchBoxBase = class SearchBoxBase extends BaseComponent {
    constructor() {
        super(...arguments);
        this.isActive = false;
        this.internalValue = this.value;
    }
    render() {
        const { classNames, disabled, internalValue, placeholder, iconName } = this;
        return (<div class={classNames.root}>
        <div class={classNames.iconContainer} role="search">
          <Icon class={classNames.icon} icon-name={iconName}/>
        </div>
        <input ref="input" {...this.$attrs} class={classNames.field} disabled={disabled} value={internalValue} area-label={placeholder} placeholder={placeholder} onInput={(ev) => (this.internalValue = ev.target.value)} onFocus={this.onFocus} onBlur={this.onBlur} onKeydown={this.onKeyDown}/>
        {internalValue && (<div class={classNames.clearButton}>
            <IconButton styles={{ root: { height: 'auto' }, icon: { fontSize: '12px' } }} icon-props={{ iconName: 'Clear' }} nativeOnClick={this.clearInput}/>
          </div>)}
      </div>);
    }
    get classNames() {
        const { theme, underlined, disabled, isActive, className, disableAnimation, internalValue } = this;
        return getClassNames(this.styles, {
            theme: theme,
            className,
            underlined,
            hasFocus: isActive,
            disabled,
            hasInput: internalValue == null ? false : internalValue.length > 0,
            disableAnimation,
        });
    }
    onPropValueChanged(newValue) {
        this.internalValue = newValue;
    }
    onValueChanged(value) {
        this.$emit('input', value);
        this.$emit('change', value);
    }
    onKeyDown(ev) {
        switch (ev.which) {
            case KeyCodes.escape:
                this.$emit('escape', ev);
                if (ev.defaultPrevented)
                    return;
                else
                    this.clearInput();
                break;
            case KeyCodes.enter:
                this.$emit('search', this.internalValue);
                return;
            default:
                if (!ev.defaultPrevented) {
                    return;
                }
        }
        // We only get here if the keypress has been handled,
        // or preventDefault was called in case of default keyDown handler
        ev.preventDefault();
        ev.stopPropagation();
    }
    submit() {
        this.$emit('search', this.internalValue);
    }
    onEscape(e) {
        this.$emit('escape', e);
        if (e.defaultPrevented)
            return;
        this.clearInput();
    }
    clearInput(e) {
        this.$emit('clear', e);
        if (e && e.defaultPrevented)
            return;
        this.internalValue = '';
        this.$refs.input.focus();
    }
    onFocus(e) {
        this.$emit('focus', e);
        if (e.defaultPrevented)
            return;
        this.isActive = true;
    }
    onBlur(e) {
        this.$emit('blur', e);
        if (e.defaultPrevented)
            return;
        this.isActive = false;
    }
};
__decorate([
    Prop({ type: Boolean, default: false }),
    __metadata("design:type", Boolean)
], SearchBoxBase.prototype, "underlined", void 0);
__decorate([
    Prop({ type: String, default: null }),
    __metadata("design:type", String)
], SearchBoxBase.prototype, "defaultValue", void 0);
__decorate([
    Prop({ type: String, default: 'Search' }),
    __metadata("design:type", String)
], SearchBoxBase.prototype, "placeholder", void 0);
__decorate([
    Prop({ type: String, default: null }),
    __metadata("design:type", String)
], SearchBoxBase.prototype, "value", void 0);
__decorate([
    Prop({ type: Boolean, default: false }),
    __metadata("design:type", Boolean)
], SearchBoxBase.prototype, "disableAnimation", void 0);
__decorate([
    Prop({ type: Boolean, default: false }),
    __metadata("design:type", Boolean)
], SearchBoxBase.prototype, "disabled", void 0);
__decorate([
    Prop({ type: String, default: 'Search' }),
    __metadata("design:type", String)
], SearchBoxBase.prototype, "iconName", void 0);
__decorate([
    Watch('value'),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String]),
    __metadata("design:returntype", void 0)
], SearchBoxBase.prototype, "onPropValueChanged", null);
__decorate([
    Watch('internalValue'),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String]),
    __metadata("design:returntype", void 0)
], SearchBoxBase.prototype, "onValueChanged", null);
SearchBoxBase = __decorate([
    Component({
        components: { Icon, IconButton },
        inheritAttrs: false,
    })
], SearchBoxBase);
export { SearchBoxBase };
//# sourceMappingURL=SearchBox.base.jsx.map