import { __decorate, __metadata } from "tslib";
import { Component, Prop, Watch } from 'vue-property-decorator';
import BaseComponent from '../BaseComponent';
import { classNamesFunction } from '@uifabric-vue/utilities';
import { ShimmerElementsGroup } from './ShimmerElementsGroup/ShimmerElementsGroup';
const getClassNames = classNamesFunction();
const TRANSITION_ANIMATION_INTERVAL = 200; /* ms */
let ShimmerBase = class ShimmerBase extends BaseComponent {
    constructor() {
        super(...arguments);
        this.contentLoaded = this.isDataLoaded;
    }
    get classNames() {
        const { theme, styles, className, shimmerColors } = this;
        return getClassNames(styles, {
            theme: theme,
            isDataLoaded: false,
            className,
            transitionAnimationInterval: TRANSITION_ANIMATION_INTERVAL,
            shimmerColor: shimmerColors && shimmerColors.shimmer,
            shimmerWaveColor: shimmerColors && shimmerColors.shimmerWave,
        });
    }
    beforeDestroy() {
        this._async.dispose();
    }
    componentDidUpdate(newVal, oldVal) {
        if (newVal === oldVal)
            return;
        if (this.isDataLoaded) {
            this.lastTimeoutId = this._async.setTimeout(() => {
                this.contentLoaded = this.isDataLoaded;
            }, TRANSITION_ANIMATION_INTERVAL);
        }
        else {
            this.contentLoaded = this.isDataLoaded;
        }
    }
    render() {
        const { classNames, width, shimmerElements, shimmerColors } = this;
        return (<div class={classNames.root}>
        <div style={{ width: width || '100%' }} class={classNames.shimmerWrapper}>
          <div class={classNames.shimmerGradient}/>
          <ShimmerElementsGroup shimmer-elements={shimmerElements} background-color={shimmerColors && shimmerColors.background}/>
        </div>
      </div>);
    }
};
__decorate([
    Prop({ default: null }),
    __metadata("design:type", Object)
], ShimmerBase.prototype, "shimmerColors", void 0);
__decorate([
    Prop({ type: Boolean, default: false }),
    __metadata("design:type", Boolean)
], ShimmerBase.prototype, "isDataLoaded", void 0);
__decorate([
    Prop({ type: Array, default: () => [] }),
    __metadata("design:type", Array)
], ShimmerBase.prototype, "shimmerElements", void 0);
__decorate([
    Prop({ type: [Number, String], default: null }),
    __metadata("design:type", Object)
], ShimmerBase.prototype, "width", void 0);
__decorate([
    Watch('isDataLoaded'),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Boolean, Boolean]),
    __metadata("design:returntype", void 0)
], ShimmerBase.prototype, "componentDidUpdate", null);
ShimmerBase = __decorate([
    Component({
        components: { ShimmerElementsGroup },
    })
], ShimmerBase);
export { ShimmerBase };
//# sourceMappingURL=Shimmer.base.jsx.map