import { __decorate, __metadata } from "tslib";
import { Component, Prop } from 'vue-property-decorator';
import { mergeStyleSets } from '@uifabric/styling';
import { getStyles as getActionButtonStyles } from '../../Button/ActionButton/ActionButton.styles';
import { memoizeFunction, classNamesFunction } from '@uifabric-vue/utilities';
import BaseComponent from '../../BaseComponent';
import { getColorFromString, GridCell } from '../../../utilities';
const getColorPickerGridCellButtonClassNames = memoizeFunction((theme, className, variantClassName, iconClassName, menuIconClassName, disabled, checked, expanded, isSplit) => {
    const styles = getActionButtonStyles(theme);
    return mergeStyleSets({
        root: [
            'ms-Button',
            styles.root,
            variantClassName,
            className,
            checked && ['is-checked', styles.rootChecked],
            disabled && ['is-disabled', styles.rootDisabled],
            !disabled &&
                !checked && {
                selectors: {
                    ':hover': styles.rootHovered,
                    ':focus': styles.rootFocused,
                    ':active': styles.rootPressed,
                },
            },
            disabled && checked && [styles.rootCheckedDisabled],
            !disabled &&
                checked && {
                selectors: {
                    ':hover': styles.rootCheckedHovered,
                    ':active': styles.rootCheckedPressed,
                },
            },
        ],
        flexContainer: ['ms-Button-flexContainer', styles.flexContainer],
    });
});
const getClassNames = classNamesFunction();
let ColorPickerGridCellBase = class ColorPickerGridCellBase extends BaseComponent {
    get classNames() {
        const { styles, theme, circle, color, disabled, selected, height, width, borderWidth } = this;
        return getClassNames(styles, {
            theme,
            disabled,
            selected,
            circle,
            isWhite: this.isWhiteCell(color),
            height,
            width,
            borderWidth,
        });
    }
    isWhiteCell(inputColor) {
        const color = getColorFromString(inputColor);
        return color.hex === 'ffffff';
    }
    render() {
        const { classNames, color, circle } = this;
        return (<GridCell class={classNames.colorCell}>
        <svg class={classNames.svg} viewBox="0 0 20 20" fill={getColorFromString(color).str}>
          {circle ? (<circle cx="50%" cy="50%" r="50%"/>) : (<rect width="100%" height="100%"/>)}
        </svg>
      </GridCell>);
    }
};
__decorate([
    Prop({ type: Boolean, default: true }),
    __metadata("design:type", Boolean)
], ColorPickerGridCellBase.prototype, "circle", void 0);
__decorate([
    Prop({ type: String }),
    __metadata("design:type", String)
], ColorPickerGridCellBase.prototype, "color", void 0);
__decorate([
    Prop({ type: Boolean }),
    __metadata("design:type", Boolean)
], ColorPickerGridCellBase.prototype, "disabled", void 0);
__decorate([
    Prop({ type: Boolean }),
    __metadata("design:type", Boolean)
], ColorPickerGridCellBase.prototype, "selected", void 0);
__decorate([
    Prop({ type: Number, default: 20 }),
    __metadata("design:type", Number)
], ColorPickerGridCellBase.prototype, "height", void 0);
__decorate([
    Prop({ type: Number, default: 20 }),
    __metadata("design:type", Number)
], ColorPickerGridCellBase.prototype, "width", void 0);
__decorate([
    Prop({ type: Number, default: 2 }),
    __metadata("design:type", Number)
], ColorPickerGridCellBase.prototype, "borderWidth", void 0);
ColorPickerGridCellBase = __decorate([
    Component({
        components: { GridCell },
    })
], ColorPickerGridCellBase);
export { ColorPickerGridCellBase };
//# sourceMappingURL=ColorPickerGridCell.base.jsx.map