import { __decorate, __metadata } from "tslib";
import { Component, Prop, Watch } from 'vue-property-decorator';
import { Label } from '../Label/';
import BaseComponent from '../BaseComponent';
import { classNamesFunction } from '@uifabric-vue/utilities';
const getClassNames = classNamesFunction();
let TextFieldBase = class TextFieldBase extends BaseComponent {
    constructor() {
        super(...arguments);
        this.isActive = false;
        this.internalValue = this.value;
    }
    get classNames() {
        const { theme, className, disabled, isActive: focused, required, multiline, label, borderless, underlined, resizable, autoAdjustHeight, } = this;
        return getClassNames(this.styles, {
            theme,
            className,
            disabled,
            focused,
            required,
            multiline,
            hasLabel: !!label,
            borderless,
            underlined,
            hasIcon: false,
            resizable: resizable !== false,
            hasErrorMessage: !!this.errorMessage,
            inputClassName: '',
            autoAdjustHeight,
        });
    }
    mounted() {
        this.adjustInputHeight();
    }
    updated() {
        this.adjustInputHeight();
    }
    onPropValueChanged(newValue) {
        this.internalValue = newValue;
    }
    async onMultilineChanged(newValue, oldValue) {
        const textElement = this.$refs.textElement;
        const start = textElement.selectionStart || 0;
        const end = textElement.selectionEnd || 0;
        if ((newValue !== oldValue) && this.isActive) {
            await this.$nextTick();
            this.$refs.textElement.focus();
            this.$refs.textElement.setSelectionRange(start, end);
        }
    }
    adjustInputHeight() {
        if (this.$refs.textElement && this.autoAdjustHeight && this.multiline) {
            const textField = this.$refs.textElement;
            textField.style.height = '';
            textField.style.height = textField.scrollHeight + 'px';
        }
    }
    async onFocus() {
        this.isActive = true;
        this.$refs.textElement.setSelectionRange(this.internalValue.length, this.internalValue.length);
    }
    onInput(ev, value) {
        this.internalValue = value;
        this.$emit('input', value);
        this.$emit('change', ev, value);
    }
    render() {
        const { classNames, required, label, errorMessage, disabled, multiline, internalValue, readonly, placeholder, resizable } = this;
        const Component = multiline ? 'textarea' : 'input';
        const labelStyles = classNames.subComponentStyles
            ? classNames.subComponentStyles.label
            : undefined;
        return (<div class={classNames.root}>
        <div class={classNames.wrapper}>
          {label && (<Label styles={labelStyles} for={`TextField${this.uid}`} required={required}>{label}</Label>)}
          <div class={classNames.fieldGroup}>
            <Component id={this.$attrs.id || `TextField${this.uid}`} ref="textElement" class={classNames.field} value={internalValue} {...{ attrs: this.$attrs }} disabled={disabled} readonly={readonly} required={required} placeholder={placeholder} rows={+this.$attrs.rows || 1} type="text" autocomplete="off" style={{ resize: (resizable === false) && 'none' }} onFocus={this.onFocus} onBlur={() => (this.isActive = false)} onInput={ev => this.onInput(ev, ev.target.value)}>{internalValue}</Component>
          </div>
        </div>
        {errorMessage && (<div class={classNames.description}>
            <div role="alert">
              <p class={classNames.errorMessage}>
                <span>{errorMessage}</span>
              </p>
            </div>
          </div>)}
      </div>);
    }
};
__decorate([
    Prop({ type: Boolean, default: false }),
    __metadata("design:type", Boolean)
], TextFieldBase.prototype, "multiline", void 0);
__decorate([
    Prop({ type: Boolean, default: null }),
    __metadata("design:type", Boolean)
], TextFieldBase.prototype, "resizable", void 0);
__decorate([
    Prop({ type: Boolean, default: null }),
    __metadata("design:type", Boolean)
], TextFieldBase.prototype, "autoAdjustHeight", void 0);
__decorate([
    Prop({ type: Boolean, default: false }),
    __metadata("design:type", Boolean)
], TextFieldBase.prototype, "borderless", void 0);
__decorate([
    Prop({ type: Boolean, default: false }),
    __metadata("design:type", Boolean)
], TextFieldBase.prototype, "disabled", void 0);
__decorate([
    Prop({ type: Boolean, default: false }),
    __metadata("design:type", Boolean)
], TextFieldBase.prototype, "underlined", void 0);
__decorate([
    Prop({ type: Boolean, default: false }),
    __metadata("design:type", Boolean)
], TextFieldBase.prototype, "readonly", void 0);
__decorate([
    Prop({ type: Boolean, default: false }),
    __metadata("design:type", Boolean)
], TextFieldBase.prototype, "required", void 0);
__decorate([
    Prop({ type: String, default: null }),
    __metadata("design:type", String)
], TextFieldBase.prototype, "label", void 0);
__decorate([
    Prop({ type: String, default: '' }),
    __metadata("design:type", String)
], TextFieldBase.prototype, "value", void 0);
__decorate([
    Prop({ type: String, default: null }),
    __metadata("design:type", String)
], TextFieldBase.prototype, "errorMessage", void 0);
__decorate([
    Prop({ type: String, default: null }),
    __metadata("design:type", String)
], TextFieldBase.prototype, "placeholder", void 0);
__decorate([
    Prop({ type: String, default: null }),
    __metadata("design:type", String)
], TextFieldBase.prototype, "description", void 0);
__decorate([
    Watch('value'),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String]),
    __metadata("design:returntype", void 0)
], TextFieldBase.prototype, "onPropValueChanged", null);
__decorate([
    Watch('multiline'),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Boolean, Boolean]),
    __metadata("design:returntype", Promise)
], TextFieldBase.prototype, "onMultilineChanged", null);
TextFieldBase = __decorate([
    Component({
        components: { Label },
        inheritAttrs: false,
    })
], TextFieldBase);
export { TextFieldBase };
//# sourceMappingURL=TextField.base.jsx.map