// import { any } from '../../Keytip'
/**
 * Builds a map of ID -> any
 *
 * @param config - IKeytipConfig object
 * @returns {IKeytipConfigMap} - Config map
 */
export function buildKeytipConfigMap(config) {
    const configMap = {};
    for (const keytip of config.keytips) {
        constructKeytip(configMap, [], keytip);
    }
    return configMap;
}
/**
 * Constructs a keytip from an IKeytipConfigItem and puts it in the configMap
 *
 * @param configMap - IKeytipConfigMap to store the keytip in
 * @param parentSequence - string of the parent keytip
 * @param keytip - IKeytipConfigItem data
 */
export function constructKeytip(configMap, parentSequence, keytip) {
    // Compute full key sequence
    const sequence = keytip.sequence ? keytip.sequence : keytip.content.toLocaleLowerCase();
    const keytipSequence = parentSequence.concat(sequence);
    // Save props in configMap
    const keytipProps = { ...keytip.optionalProps, keySequences: keytipSequence, content: keytip.content };
    configMap[keytip.id] = keytipProps;
    if (keytip.children) {
        for (const child of keytip.children) {
            // Create keytips for all children
            constructKeytip(configMap, keytipSequence, child);
        }
    }
}
//# sourceMappingURL=KeytipConfig.js.map